@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -43,7 +44,7 @@ $authobj = AuthFactory::create($USER->authinstance);
 if (method_exists($authobj, 'change_password')) {
     $elements = array(
         'changepassworddesc' => array(
-            'value' => '<tr><td colspan="2"><p>' . get_string('changepassworddesc', 'account') . '</p></td></tr>'
+            'value' => '<tr><td colspan="2"><h3>' . get_string('changepassworddesc', 'account') . '</h3></td></tr>'
         ),
         'oldpassword' => array( 'type' => 'password',
             'title' => get_string('oldpassword'),
@@ -64,7 +65,7 @@ else if ($url = get_config_plugin_instance('auth', $USER->authinstance, 'changep
     // @todo contextual help
     $elements = array(
         'changepasswordotherinterface' => array(
-            'value' => '<tr><td colspan="2"><p>' . get_string('changepasswordotherinterface', 'account', $url) . '</p></td></tr>'
+            'value' => '<tr><td colspan="2"><h3>' . get_string('changepasswordotherinterface', 'account', $url) . '</h3></td></tr>'
         )
     );
 }
@@ -72,14 +73,26 @@ else {
     $elements = array();
 }
 
+if ($authobj->authname == 'internal') {
+    $elements['changeusernameheading'] = array(
+        'value' => '<tr><td colspan="2"><h3>' . get_string('changeusernameheading', 'account') . '</h3></td></tr>'
+    );
+    $elements['username'] = array(
+        'type' => 'text',
+        'defaultvalue' => $USER->get('username'),
+        'title' => get_string('changeusername', 'account'),
+        'description' => get_string('changeusernamedesc', 'account', hsc(get_config('sitename'))),
+    );
+}
+
 $elements['accountoptionsdesc'] = array(
-    'value' => '<tr><td colspan="2"><p>' . get_string('accountoptionsdesc', 'account') . '</p></td></tr>'
+    'value' => '<tr><td colspan="2"><h3>' . get_string('accountoptionsdesc', 'account') . '</h3></td></tr>'
 );
 $elements['friendscontrol'] = array(
     'type' => 'radio',
     'defaultvalue' => $prefs->friendscontrol, 
     'title'  => get_string('friendsdescr', 'account'),
-    'separator' => HTML_BR,
+    'separator' => '<br>',
     'options' => array(
         'nobody' => get_string('friendsnobody', 'account'),
         'auth'   => get_string('friendsauth', 'account'),
@@ -91,6 +104,7 @@ $elements['wysiwyg'] = array(
     'type' => 'radio',
     'defaultvalue' => $prefs->wysiwyg,
     'title' => get_string('wysiwygdescr', 'account'),
+    'separator' => '<br>',
     'options' => array(
         1 => get_string('on', 'account'),
         0 => get_string('off', 'account'),
@@ -101,7 +115,7 @@ $elements['messages'] = array(
     'type' => 'radio',
     'defaultvalue' => $prefs->messages,
     'title' => get_string('messagesdescr', 'account'),
-    'separator' => HTML_BR,
+    'separator' => '<br>',
     'options' => array(
         'nobody' => get_string('messagesnobody', 'account'),
         'friends' => get_string('messagesfriends', 'account'),
@@ -126,8 +140,19 @@ $elements['addremovecolumns'] = array(
     ),
     'defaultvalue' => $prefs->addremovecolumns,
     'title' => get_string('showviewcolumns', 'account'),
+    'separator' => '<br>',
     'help' => 'true'
 );
+if (get_config('showtagssideblock')) {
+    $elements['tagssideblockmaxtags'] = array(
+        'type'         => 'text',
+        'size'         => 4,
+        'title'        => get_string('tagssideblockmaxtags', 'account'),
+        'description'  => get_string('tagssideblockmaxtagsdescription', 'account'),
+        'defaultvalue' => isset($prefs->tagssideblockmaxtags) ? $prefs->tagssideblockmaxtags : get_config('tagssideblockmaxtags'),
+        'rules'        => array('integer' => true, 'minvalue' => 0, 'maxvalue' => 1000),
+    );
+}
 $elements['submit'] = array(
     'type' => 'submit',
     'value' => get_string('save')
@@ -152,9 +177,17 @@ function accountprefs_validate(Pieform $form, $values) {
     if (isset($values['oldpassword'])) {
         if ($values['oldpassword'] !== '') {
             global $USER, $authtype, $authclass;
-            if (!$authobj->authenticate_user_account($USER, $values['oldpassword'])) {
-                $form->set_error('oldpassword', get_string('oldpasswordincorrect', 'account'));
-                return;
+            try {
+                if (!$authobj->authenticate_user_account($USER, $values['oldpassword'])) {
+                    $form->set_error('oldpassword', get_string('oldpasswordincorrect', 'account'));
+                    return;
+                }
+            }
+            // propagate error correctly for User validation issues - this should
+            // be catching AuthUnknownUserException and AuthInstanceException
+             catch  (UserException $e) {
+                 $form->set_error('oldpassword', $e->getMessage());
+                 return;
             }
             password_validate($form, $values, $USER);
         }
@@ -162,6 +195,15 @@ function accountprefs_validate(Pieform $form, $values) {
             $form->set_error('oldpassword', get_string('mustspecifyoldpassword'));
         }
     }
+
+    if ($authobj->authname == 'internal' && $values['username'] != $USER->get('username')) {
+        if (!AuthInternal::is_username_valid($values['username'])) {
+            $form->set_error('username', get_string('usernameinvalidform', 'auth.internal'));
+        }
+        if (!$form->get_error('username') && record_exists_select('usr', 'LOWER(username) = ?', strtolower($values['username']))) {
+            $form->set_error('username', get_string('usernamealreadytaken', 'auth.internal'));
+        }
+    }
 }
 
 function accountprefs_submit(Pieform $form, $values) {
@@ -186,15 +228,26 @@ function accountprefs_submit(Pieform $form, $values) {
         }
     }
 
+    $returndata = array();
+
+    if (isset($values['username']) && $values['username'] != $USER->get('username')) {
+        $USER->username = $values['username'];
+        $USER->commit();
+        $returndata['username'] = $values['username'];
+    }
+
     db_commit();
-    $form->json_reply(PIEFORM_OK, get_string('prefssaved', 'account'));
+    $returndata['message'] = get_string('prefssaved', 'account');
+    $form->json_reply(PIEFORM_OK, $returndata);
 }
 
 
 
+$prefsform = pieform($prefsform);
 
 $smarty = smarty();
-$smarty->assign('form', pieform($prefsform));
+$smarty->assign('form', $prefsform);
+$smarty->assign('candeleteself', $USER->can_delete_self());
 $smarty->assign('INLINEJAVASCRIPT', "
 function clearPasswords(form, data) {
     formSuccess(form, data);
@@ -203,8 +256,13 @@ function clearPasswords(form, data) {
         $('accountprefs_password1').value = '';
         $('accountprefs_password2').value = '';
     }
-}");
-$smarty->assign('heading', get_string('preferences'));
+    if (data.username) {
+        var username = getFirstElementByTagAndClassName('a', null, 'profile-sideblock-username');
+        replaceChildNodes(username, data.username);
+    }
+}
+");
+$smarty->assign('PAGEHEADING', hsc(get_string('preferences')));
 $smarty->display('account/index.tpl');
 
 
