@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage admin
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -32,6 +33,7 @@ define('TITLE', get_string('uploadcsv', 'admin'));
 require_once('pieforms/pieform.php');
 require_once('institution.php');
 safe_require('artefact', 'internal');
+raise_memory_limit("512M");
 
 // Turn on autodetecting of line endings, so mac newlines (\r) will work
 ini_set('auto_detect_line_endings', 1);
@@ -67,6 +69,7 @@ $ALLOWEDKEYS = array(
     'industry',
     'authinstance'
 );
+$CSVERRORS = array();
 
 if ($USER->get('admin')) {
     $authinstances = auth_get_auth_instances();
@@ -74,7 +77,7 @@ if ($USER->get('admin')) {
     $admininstitutions = $USER->get('admininstitutions');
     $authinstances = auth_get_auth_instances_for_institutions($admininstitutions);
     if (empty($authinstances)) {
-        $SESSION->add_info_msg(get_string('uploadcsvconfigureauthplugin', 'admin'));
+        $SESSION->add_info_msg(get_string('configureauthplugin', 'admin'));
         redirect(get_config('wwwroot').'admin/users/institutions.php?i='.key($admininstitutions).'&amp;edit=1');
     }
 }
@@ -84,7 +87,7 @@ if (count($authinstances) > 0) {
 
     foreach ($authinstances as $authinstance) {
         if ($USER->can_edit_institution($authinstance->name)) {
-            $options[$authinstance->id .'_'. $authinstance->name] = $authinstance->displayname. ': '.$authinstance->instancename;
+            $options[$authinstance->id] = $authinstance->displayname. ': '.$authinstance->instancename;
         }
     }
     $default = key($options);
@@ -138,7 +141,7 @@ $form = array(
  * @param array    $values The values submitted
  */
 function uploadcsv_validate(Pieform $form, $values) {
-    global $CSVDATA, $ALLOWEDKEYS, $FORMAT, $USER;
+    global $CSVDATA, $ALLOWEDKEYS, $FORMAT, $USER, $CSVERRORS;
 
     // Don't even start attempting to parse if there are previous errors
     if ($form->has_errors()) {
@@ -150,13 +153,10 @@ function uploadcsv_validate(Pieform $form, $values) {
         return;
     }
 
-    require_once('pear/File.php');
-    require_once('pear/File/CSV.php');
+    require_once('csvfile.php');
 
-    // Don't be tempted to use 'explode' here. There may be > 1 underscore.
-    $break = strpos($values['authinstance'], '_');
-    $authinstance = substr($values['authinstance'], 0, $break);
-    $institution  = substr($values['authinstance'], $break+1);
+    $authinstance = (int) $values['authinstance'];
+    $institution = get_field('auth_instance', 'institution', 'id', $authinstance);
     if (!$USER->can_edit_institution($institution)) {
         $form->set_error('authinstance', get_string('notadminforinstitution', 'admin'));
         return;
@@ -164,102 +164,77 @@ function uploadcsv_validate(Pieform $form, $values) {
 
     $usernames = array();
     $emails = array();
-    $conf = File_CSV::discoverFormat($values['file']['tmp_name']);
-    $i = 0;
-    while ($line = File_CSV::readQuoted($values['file']['tmp_name'], $conf)) {
-        $i++;
-        if (!is_array($line)) {
-            // Note: the CSV parser returns true on some errors and false on
-            // others! Yes that's retarded. No I didn't write it :(
-            $form->set_error('file', get_string('uploadcsverrorincorrectnumberoffields', 'admin', $i));
-            return;
-        }
 
-        // Get the format of the file
-        if ($i == 1) {
-            foreach ($line as &$potentialkey) {
-                $potentialkey = trim($potentialkey);
-                if (!in_array($potentialkey, $ALLOWEDKEYS)) {
-                    $form->set_error('file', get_string('uploadcsverrorinvalidfieldname', 'admin', $potentialkey));
-                    return;
-                }
-            }
-
-            // Now we know all of the field names are valid, we need to make
-            // sure that the required fields are included
-            $mandatoryfields = array(
-                'username',
-                'password'
-            );
-            $mandatoryfields = array_merge($mandatoryfields, array_keys(ArtefactTypeProfile::get_mandatory_fields()));
-            if ($lockedprofilefields = get_column('institution_locked_profile_field', 'profilefield', 'name', $institution)) {
-                $mandatoryfields = array_merge($mandatoryfields, $lockedprofilefields);
-            }
-            
-            // Add in the locked profile fields for this institution
-            foreach ($mandatoryfields as $field) {
-                if (!in_array($field, $line)) {
-                    $form->set_error('file', get_string('uploadcsverrorrequiredfieldnotspecified', 'admin', $field));
-                    return;
-                }
-            }
-
-            // The format line is valid
-            $FORMAT = $line;
-            log_info('FORMAT:');
-            log_info($FORMAT);
-        }
-        else {
-            // We have a line with the correct number of fields, but should validate these fields
-            // Note: This validation should really be methods on each profile class, that way
-            // it can be used in the profile screen as well.
-
-            $formatkeylookup = array_flip($FORMAT);
-            $username = $line[$formatkeylookup['username']];
-            $password = $line[$formatkeylookup['password']];
-            $email    = $line[$formatkeylookup['email']];
-
-            $authobj = AuthFactory::create($authinstance);
-
-            if (method_exists($authobj, 'is_username_valid') && !$authobj->is_username_valid($username)) {
-                $form->set_error('file', get_string('uploadcsverrorinvalidusername', 'admin', $i));
-                return;
-            }
-            if (record_exists_select('usr', 'LOWER(username) = ?', strtolower($username)) || isset($usernames[strtolower($username)])) {
-                $form->set_error('file', get_string('uploadcsverroruseralreadyexists', 'admin', $i, $username));
-                return;
-            }
-            if (record_exists('usr', 'email', $email) || isset($emails[$email])) {
-                $form->set_error('file', get_string('uploadcsverroremailaddresstaken', 'admin', $i, $email));
-            }
-
-            // Note: only checks for valid form are done here, none of the checks
-            // like whether the password is too easy. The user is going to have to
-            // change their password on first login anyway.
-            if (method_exists($authobj, 'is_password_valid') && !$authobj->is_password_valid($password)) {
-                $form->set_error('file', get_string('uploadcsverrorinvalidpassword', 'admin', $i));
-                return;
-            }
-
-            $usernames[strtolower($username)] = 1;
-            $emails[$email] = 1;
-
-            // All OK!
-            $CSVDATA[] = $line;
-        }
+    $csvusers = new CsvFile($values['file']['tmp_name']);
+    $csvusers->set('allowedkeys', $ALLOWEDKEYS);
 
+    // Now we know all of the field names are valid, we need to make
+    // sure that the required fields are included
+    $mandatoryfields = array(
+        'username',
+        'password'
+    );
+    $mandatoryfields = array_merge($mandatoryfields, array_keys(ArtefactTypeProfile::get_mandatory_fields()));
+    if ($lockedprofilefields = get_column('institution_locked_profile_field', 'profilefield', 'name', $institution)) {
+        $mandatoryfields = array_merge($mandatoryfields, $lockedprofilefields);
     }
 
-    if ($i == 1) {
-        // There was only the title row :(
-        $form->set_error('file', get_string('uploadcsverrornorecords', 'admin'));
+    $csvusers->set('mandatoryfields', $mandatoryfields);
+    $csvdata = $csvusers->get_data();
+
+    if (!empty($csvdata->errors['file'])) {
+        $form->set_error('file', $csvdata->errors['file']);
         return;
     }
 
-    if ($CSVDATA === null) {
-        // Oops! Couldn't get CSV data for some reason
-        $form->set_error('file', get_string('uploadcsverrorunspecifiedproblem', 'admin'));
+    foreach ($csvdata->data as $key => $line) {
+        // If headers exists, increment i = key + 2 for actual line number
+        $i = ($csvusers->get('headerExists')) ? ($key + 2) : ($key + 1);
+
+        // Trim non-breaking spaces -- they get left in place by File_CSV
+        foreach ($line as &$field) {
+            $field = preg_replace('/^(\s|\xc2\xa0)*(.*?)(\s|\xc2\xa0)*$/', '$2', $field);
+        }
+
+        // We have a line with the correct number of fields, but should validate these fields
+        // Note: This validation should really be methods on each profile class, that way
+        // it can be used in the profile screen as well.
+
+        $formatkeylookup = array_flip($csvdata->format);
+        $username = $line[$formatkeylookup['username']];
+        $password = $line[$formatkeylookup['password']];
+        $email    = $line[$formatkeylookup['email']];
+
+        $authobj = AuthFactory::create($authinstance);
+
+        if (method_exists($authobj, 'is_username_valid') && !$authobj->is_username_valid($username)) {
+            $CSVERRORS[] = get_string('uploadcsverrorinvalidusername', 'admin', $i);
+        }
+        if (record_exists_select('usr', 'LOWER(username) = ?', strtolower($username)) || isset($usernames[strtolower($username)])) {
+            $CSVERRORS[] = get_string('uploadcsverroruseralreadyexists', 'admin', $i, $username);
+        }
+        if (record_exists('usr', 'email', $email) || record_exists('artefact_internal_profile_email', 'email', $email) || isset($emails[$email])) {
+            $CSVERRORS[] = get_string('uploadcsverroremailaddresstaken', 'admin', $i, $email);
+        }
+
+        // Note: only checks for valid form are done here, none of the checks
+        // like whether the password is too easy. The user is going to have to
+        // change their password on first login anyway.
+        if (method_exists($authobj, 'is_password_valid') && !$authobj->is_password_valid($password)) {
+            $CSVERRORS[] = get_string('uploadcsverrorinvalidpassword', 'admin', $i);
+        }
+
+        $usernames[strtolower($username)] = 1;
+        $emails[$email] = 1;
     }
+
+    if (!empty($CSVERRORS)) {
+        $form->set_error('file', implode("<br />\n", $CSVERRORS));
+        return;
+    }
+
+    $FORMAT = $csvdata->format;
+    $CSVDATA = $csvdata->data;
 }
 
 /**
@@ -271,11 +246,10 @@ function uploadcsv_submit(Pieform $form, $values) {
 
     $formatkeylookup = array_flip($FORMAT);
 
-    // Don't be tempted to use 'explode' here. There may be > 1 underscore.
-    $break = strpos($values['authinstance'], '_');
-    $authinstance = substr($values['authinstance'], 0, $break);
-    $institution = substr($values['authinstance'], $break+1);
-    $institution = new Institution($institution);
+    $authinstance = (int) $values['authinstance'];
+    $authobj = get_record('auth_instance', 'id', $authinstance);
+
+    $institution = new Institution($authobj->institution);
 
     $maxusers = $institution->maxuseraccounts; 
     if (!empty($maxusers)) {
@@ -309,29 +283,17 @@ function uploadcsv_submit(Pieform $form, $values) {
             $user->preferredname = $record[$formatkeylookup['preferredname']];
         }
         $user->passwordchange = (int)$values['forcepasswordchange'];
-        $id = insert_record('usr', $user, 'id', true);
-        $user->id = $id;
-        if ($institution->name != 'mahara') {
-            $institution->addUserAsMember($user);
-        }
-        if (get_field('auth_instance', 'authname', 'id', $authinstance) != 'internal') {
-            // Assume the admin knows what they're doing when they choose the external auth instance.
-            delete_records('auth_remote_user', 'authinstance', $authinstance, 'remoteusername', $user->username);
-            insert_record('auth_remote_user', (object) array(
-                'authinstance'   => $authinstance,
-                'remoteusername' => $user->username,
-                'localusr'       => $id,
-            ));
-        }
 
+        $profilefields = new StdClass;
         foreach ($FORMAT as $field) {
             if ($field == 'username' || $field == 'password') {
                 continue;
             }
-            set_profile_field($id, $field, $record[$formatkeylookup[$field]]);
+            $profilefields->{$field} = $record[$formatkeylookup[$field]];
         }
 
-        handle_event('createuser', $user);
+        $user->id = create_user($user, $profilefields, $institution, $authobj);
+
         if ($values['emailusers']) {
             $addedusers[] = $user;
         }
@@ -346,9 +308,9 @@ function uploadcsv_submit(Pieform $form, $values) {
         foreach ($addedusers as $user) {
             $failedusers = array();
             try {
-                email_user($user, null, get_string('accountcreated'),
-                    get_string($straccountcreatedtext, 'mahara', $user->firstname, get_config('sitename'), $user->username, $user->password, get_config('sitename')),
-                    get_string($straccountcreatedhtml, 'mahara', $user->firstname, get_config('sitename'), $user->username, $user->password, get_config('sitename'))
+                email_user($user, null, get_string('accountcreated', 'mahara', get_config('sitename')),
+                    get_string($straccountcreatedtext, 'mahara', $user->firstname, get_config('sitename'), $user->username, $user->password, get_config('wwwroot'), get_config('sitename')),
+                    get_string($straccountcreatedhtml, 'mahara', $user->firstname, get_config('wwwroot'), get_config('sitename'), $user->username, $user->password, get_config('wwwroot'), get_config('wwwroot'), get_config('sitename'))
                 );
             }
             catch (EmailException $e) {
@@ -375,14 +337,14 @@ function uploadcsv_submit(Pieform $form, $values) {
 
 // Get a list of all profile fields, to inform the user on what fields they can
 // put in their file.
-$fields = "<ul>\n";
+$fields = "<ul class=fieldslist>\n";
 foreach (array_keys(ArtefactTypeProfile::get_all_fields()) as $type) {
     if ($type == 'firstname' || $type == 'lastname' || $type == 'email') {
         continue;
     }
     $fields .= '<li>' . hsc($type) . "</li>\n";
 }
-$fields .= "</ul>\n";
+$fields .= "<div class=cl></div></ul>\n";
 
 if ($USER->get('admin')) {
     $uploadcsvpagedescription = get_string('uploadcsvpagedescription2', 'admin',
@@ -398,9 +360,12 @@ else {
     );
 }
 
+$form = pieform($form);
+
 $smarty = smarty();
 $smarty->assign('uploadcsvpagedescription', $uploadcsvpagedescription);
-$smarty->assign('uploadcsvform', pieform($form));
+$smarty->assign('uploadcsvform', $form);
+$smarty->assign('PAGEHEADING', hsc(TITLE));
 $smarty->display('admin/users/uploadcsv.tpl');
 
 ?>
