@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage auth
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -121,10 +122,8 @@ function api_dummy_method($methodname, $argsarray, $functionname) {
     return call_user_func_array($functionname, $argsarray);
 }
 
-function fetch_user_image($username) {
-    global $REMOTEWWWROOT;
-
-    $institution = get_field('host', 'institution', 'wwwroot', $REMOTEWWWROOT);
+function find_remote_user($username, $wwwroot) {
+    $institution = get_field('host', 'institution', 'wwwroot', $wwwroot);
 
     if (false == $institution) {
         // This should never happen, because if we don't know the host we'll
@@ -134,7 +133,12 @@ function fetch_user_image($username) {
 
     $authinstances = auth_get_auth_instances_for_institution($institution);
     $candidates    = array();
+    $auths         = array();
 
+    $aiid = 'ai.id';
+    if (!is_mysql()) {
+        $aiid = 'CAST(ai.id AS TEXT)';
+    }
     $sql = 'SElECT
                 ai.*
             FROM
@@ -145,7 +149,7 @@ function fetch_user_image($username) {
                 ai.id = ? AND
                 ai.institution = ? AND
                 ai2.institution = ai.institution AND
-                ai.id = aic.value AND
+                ' . $aiid . ' = aic.value AND
                 aic.field = \'parent\' AND
                 aic.instance = ai2.id AND
                 ai2.authname = \'xmlrpc\'';
@@ -161,21 +165,32 @@ function fetch_user_image($username) {
             $user = new User;
             $user->find_by_instanceid_username($authinstance->id, $username, true);
             $candidates[$user->id] = $user;
+            $auths[] = $authinstance->id;
         } catch (Exception $e) {
             // we don't care
             continue;
-        } 
+        }
     }
 
     if (count($candidates) != 1) {
         return false;
     }
 
-    $user = array_pop($candidates);
-    
+    safe_require('auth', 'xmlrpc');
+    return array(array_pop($candidates), new AuthXmlrpc(array_pop($auths)));
+}
+
+function fetch_user_image($username) {
+    global $REMOTEWWWROOT;
+
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        return false;
+    }
+
     $ic = $user->profileicon;
     if (!empty($ic)) {
-        $filename = get_config('dataroot') . 'artefact/internal/profileicons/' . ($user->profileicon % 256) . '/'.$user->profileicon;
+        $filename = get_config('dataroot') . 'artefact/file/profileicons/' . ($user->profileicon % 256) . '/'.$user->profileicon;
         $return = array();
         try {
             $fi = file_get_contents($filename);
@@ -186,7 +201,7 @@ function fetch_user_image($username) {
         $return['f1'] = base64_encode($fi);
 
         require_once('file.php');
-        $im = get_dataroot_image_path('artefact/internal/profileicons' , $user->profileicon, 100);
+        $im = get_dataroot_image_path('artefact/file/profileicons' , $user->profileicon, 100);
         $fi = file_get_contents($im);
         $return['f2'] = base64_encode($fi);
         return $return;
@@ -216,8 +231,8 @@ function user_authorise($token, $useragent) {
         throw new XmlrpcServerException('Unable to get information for the specified user');
     }
 
-    require(get_config('docroot') . 'artefact/lib.php');
-    require(get_config('docroot') . 'artefact/internal/lib.php');
+    require_once(get_config('docroot') . 'artefact/lib.php');
+    require_once(get_config('docroot') . 'artefact/internal/lib.php');
 
     $element_list = call_static_method('ArtefactTypeProfile', 'get_all_fields');
     $element_required = call_static_method('ArtefactTypeProfile', 'get_mandatory_fields');
@@ -246,7 +261,7 @@ function user_authorise($token, $useragent) {
     $userdata['country']                 = array_key_exists('country', $profile_data) ? $profile_data['country']->title : '';
 
     if (is_numeric($user->profileicon)) {
-        $filename = get_config('dataroot') . 'artefact/internal/profileicons/' . ($user->profileicon % 256) . '/'.$user->profileicon;
+        $filename = get_config('dataroot') . 'artefact/file/profileicons/' . ($user->profileicon % 256) . '/'.$user->profileicon;
         if (file_exists($filename) && is_readable($filename)) {
             $userdata['imagehash'] = sha1_file($filename);
         }
@@ -260,6 +275,102 @@ function user_authorise($token, $useragent) {
     return $userdata;
 }
 
+function send_content_intent($username) {
+    global $REMOTEWWWROOT;
+    require_once(get_config('docroot') . 'import/lib.php');
+
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        throw new ImportException(null, "Could not find user $username for $REMOTEWWWROOT");
+    }
+
+    if (!is_executable(get_config('pathtounzip'))) {
+        throw new ImportException(null, "Cannot find unzip executable");
+    }
+
+    if (!$authinstance->weimportcontent) {
+        $e = new ImportException(null, 'Importing content is disabled');
+        $e->set_log_off(); // we don't want these ones.
+        throw $e;
+    }
+
+    $queue = PluginImport::create_new_queue($user->id, null, $REMOTEWWWROOT, 0);
+
+    return array(
+        'sendtype' => (($queue->queue) ? 'queue' : 'immediate'),
+        'token' => $queue->token,
+    );
+}
+
+function send_content_ready($token, $username, $format, $importdata, $fetchnow=false) {
+    global $REMOTEWWWROOT;
+    require_once(get_config('docroot') . 'import/lib.php');
+
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        throw new ImportException(null, "Could not find user $username for $REMOTEWWWROOT");
+    }
+
+    // go verify the token
+    if (!$queue = get_record('import_queue', 'token', $token, 'host', $REMOTEWWWROOT)) {
+        throw new ImportException(null, "Could not find queue record with given token for username $username for $REMOTEWWWROOT");
+    }
+
+    if (strtotime($queue->expirytime) < time()) {
+        throw new ImportException(null, "Queue record has expired");
+    }
+
+    $queue->format = $format;
+    $class = null;
+    try {
+        $class = PluginImport::class_from_format($format);
+    } catch (Exception $e) {
+        throw new ImportException(null, "Invalid format $format");
+    }
+    try {
+        call_static_method($class, 'validate_import_data', $importdata);
+    } catch (Exception $e) {
+        throw new ImportException(null, 'Invalid importdata: ' . $e->getMessage());
+    }
+
+    if (!array_key_exists('totalsize', $importdata)) {
+        throw new ImportException(null, 'Invalid importdata: missing totalsize');
+    }
+
+    if (!$user->quota_allowed($importdata['totalsize'])) {
+        $e = new ImportException(null, 'Exceeded user quota');
+        $e->set_log_off();
+        throw $e;
+    }
+
+    $queue->data = serialize($importdata);
+
+    update_record('import_queue', $queue);
+
+    $result = new StdClass;
+    if ($fetchnow && PluginImport::import_immediately_allowed()) {
+        // either immediately spawn a curl request to go fetch the file
+        $importer = PluginImport::create_importer($queue->id, $queue);
+        $importer->prepare();
+        $importer->process();
+        $importer->cleanup();
+        delete_records('import_queue', 'id', $queue->id);
+        $result->status = true;
+        $result->type = 'complete';
+        $returndata = $importer->get_return_data();
+        $result->querystring = '?';
+        foreach ($importer->get_return_data() as $k => $v) {
+            $result->querystring .= $k . '=' . $v . '&';
+        }
+        $importer->get('importertransport')->cleanup();
+    } else {
+        // or set ready to 1 for the next cronjob to go fetch it.
+        $result->status = set_field('import_queue', 'ready', 1, 'id', $queue->id);
+        $result->type = 'queued';
+    }
+    return $result;
+}
+
 /**
  * If we're an IDP, kill_children will kill the session of the given user here, 
  * as well as at any other children
@@ -338,6 +449,90 @@ function xmlrpc_not_implemented() {
     return true;
 }
 
+function get_views_for_user($username, $query=null) {
+    global $REMOTEWWWROOT, $USER;
+
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        return false;
+    }
+
+    $USER->reanimate($user->id, $authinstance->instanceid);
+    require_once('view.php');
+    $data = View::view_search($query, null, (object) array('owner' => $USER->get('id')));
+    $data->displayname = display_name($user);
+    if ($data->count) {
+        foreach ($data->data as &$v) {
+            $v['url'] = '/view/view.php?id=' . $v['id'];
+            $v['fullurl'] = get_config('wwwroot') . 'view/view.php?id=' . $v['id'];
+        }
+    }
+    return $data;
+}
+
+function submit_view_for_assessment($username, $viewid) {
+    global $REMOTEWWWROOT;
+
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        return false;
+    }
+
+    $viewid = (int) $viewid;
+    if (!$viewid) {
+        return false;
+    }
+
+    require_once('view.php');
+    $view = new View($viewid);
+
+    $view->set('submittedhost', $authinstance->config['wwwroot']);
+
+    // Create secret key
+    $access = View::new_token($view->get('id'), false);
+
+    $data = array(
+        'id'          => $view->get('id'),
+        'title'       => $view->get('title'),
+        'description' => $view->get('description'),
+        'fullurl'     => get_config('wwwroot') . 'view/view.php?id=' . $view->get('id') . '&mt=' . $access->token,
+        'url'         => '/view/view.php?id=' . $view->get('id') . '&mt=' . $access->token,
+        'accesskey'   => $access->token,
+    );
+
+    foreach (plugins_installed('artefact') as $plugin) {
+        safe_require('artefact', $plugin->name);
+        $classname = generate_class_name('artefact', $plugin->name);
+        if (is_callable($classname . '::view_submit_external_data')) {
+            $data[$plugin->name] = call_static_method($classname, 'view_submit_external_data', $view->get('id'));
+        }
+    }
+
+    return $data;
+}
+
+function release_submitted_view($viewid, $assessmentdata, $teacherusername) {
+    global $REMOTEWWWROOT, $USER;
+
+    require_once('view.php');
+    $view = new View($viewid);
+    list ($teacher, $authinstance) = find_remote_user($teacherusername, $REMOTEWWWROOT);
+
+    db_begin();
+    foreach (plugins_installed('artefact') as $plugin) {
+        safe_require('artefact', $plugin->name);
+        $classname = generate_class_name('artefact', $plugin->name);
+        if (is_callable($classname . '::view_release_external_data')) {
+            call_static_method($classname, 'view_release_external_data', $view, $assessmentdata, $teacher ? $teacher->id : 0);
+        }
+    }
+
+    // Release the view for editing
+    $view->set('submittedhost', null);
+    $view->commit();
+    db_commit();
+}
+
 /**
  * Given a USER, get all Service Providers for that User, based on child auth
  * instances of its canonical auth instance
@@ -419,21 +614,25 @@ function get_public_key($uri, $application=null) {
     $wwwroot = dropslash(get_config('wwwroot'));
 
     $rq = xmlrpc_encode_request('system/keyswap', array($wwwroot, $openssl->certificate), array("encoding" => "utf-8"));
-    $ch = curl_init($uri . $xmlrpcserverurl);
 
-    curl_setopt($ch, CURLOPT_TIMEOUT, 60);
-    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
-    curl_setopt($ch, CURLOPT_POST, true);
-    curl_setopt($ch, CURLOPT_USERAGENT, 'Moodle');
-    curl_setopt($ch, CURLOPT_POSTFIELDS, $rq);
-    curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: text/xml charset=UTF-8", 'Expect: '));
+    $config = array(
+        CURLOPT_URL => $uri . $xmlrpcserverurl,
+        CURLOPT_POST => true,
+        CURLOPT_USERAGENT => 'Moodle',
+        CURLOPT_POSTFIELDS => $rq,
+        CURLOPT_HTTPHEADER => array("Content-Type: text/xml charset=UTF-8", 'Expect: '),
+    );
 
-    $raw = curl_exec($ch);
-    if (empty($raw)) {
+    $result = mahara_http_request($config);
+
+    if (!empty($result->errno)) {
+        throw new XmlrpcClientException('Curl error: ' . $result->errno . ': ' . $result->error);
+    }
+    if (empty($result->data)) {
         throw new XmlrpcClientException('CURL connection failed');
     }
 
-    $response_code        = curl_getinfo($ch, CURLINFO_HTTP_CODE);
+    $response_code        = $result->info['http_code'];
     $response_code_prefix = substr($response_code, 0, 1);
 
     if ('2' != $response_code_prefix) {
@@ -444,8 +643,7 @@ function get_public_key($uri, $application=null) {
         }
     }
 
-    $res = xmlrpc_decode($raw);
-    curl_close($ch);
+    $res = xmlrpc_decode($result->data);
 
     // XMLRPC error messages are returned as an array
     // We are expecting a string
@@ -458,6 +656,7 @@ function get_public_key($uri, $application=null) {
             if (strpos($uri, $host) !== false) {
                 return $keyarray[$uri];
             }
+            throw new XmlrpcClientException('The remote site sent us a key that is valid for ' . $host . ' instead of their hostname (' . $uri . ')', 500);
         }
     } else {
         throw new XmlrpcClientException($res['faultString'], $res['faultCode']);
@@ -527,12 +726,24 @@ function get_peer($wwwroot, $cache=true) {
 
     if (!$peer->findByWwwroot($wwwroot)) {
         // Bootstrap unknown hosts?
-        throw new MaharaException('We don\'t have a record for your webserver in our database', 6003);
+        throw new MaharaException("We don't have a record for your webserver ($wwwroot) in our database", 6003);
     }
     $peers[$wwwroot] = $peer;
     return $peers[$wwwroot];
 }
 
+function get_peer_from_instanceid($authinstanceid) {
+    $sql = 'SELECT
+                h.*
+            FROM
+                {auth_instance_config} aic,
+                {host} h
+            WHERE
+                aic.value = h.wwwroot AND
+                aic.instance = ? AND aic.field = \'wwwroot\'';
+    return get_record_sql($sql, array($authinstanceid));
+}
+
 /**
  * Check that the signature has been signed by the remote host.
  */
@@ -816,6 +1027,7 @@ class OpenSslRepo {
     private function __construct() {
         if (empty($this->keypair)) {
             $this->get_keypair();
+	    $this->calculate_fingerprints();
             $this->keypair['privatekey'] = openssl_pkey_get_private($this->keypair['keypair_PEM']);
             $this->keypair['publickey']  = openssl_pkey_get_public($this->keypair['certificate']);
         }
@@ -875,6 +1087,8 @@ class OpenSslRepo {
     public function __get($name) {
         if ('certificate' === $name) return $this->keypair['certificate'];
         if ('expires' === $name)     return $this->keypair['expires'];
+        if ('sha1_fingerprint' === $name) return $this->keypair['sha1_fingerprint'];
+        if ('md5_fingerprint' === $name ) return $this->keypair['md5_fingerprint'];
         return null;
     }
 
@@ -979,8 +1193,16 @@ class OpenSslRepo {
         // ensure we remove trailing slashes
         $dn["commonName"] = preg_replace(':/$:', '', $dn["commonName"]);
 
-        $new_key = openssl_pkey_new();
-        $csr_rsc = openssl_csr_new($dn, $new_key, array('private_key_bits',2048));
+        if (!$new_key = openssl_pkey_new()) {
+            throw new ConfigException(get_string('errorcouldnotgeneratenewsslkey', 'auth'));
+        }
+
+        if (!$csr_rsc = openssl_csr_new($dn, $new_key, array('private_key_bits',2048))) {
+            // This behaviour has been observed once before, on an ubuntu hardy box. 
+            // The php5-openssl package was installed but somehow openssl 
+            // wasn't.
+            throw new ConfigException(get_string('errorcouldnotgeneratenewsslkey', 'auth'));
+        }
         $selfSignedCert = openssl_csr_sign($csr_rsc, null, $new_key, 365 /*days*/);
         unset($csr_rsc); // Free up the resource
 
@@ -994,8 +1216,81 @@ class OpenSslRepo {
         openssl_pkey_free($new_key);
         unset($new_key); // Free up the resource
 
+        // Calculate fingerprints
+        $this->calculate_fingerprints();
+
         return $this;
     }
+
+
+    /**
+     * Calculates the SHA1 and MD5 fingerprints of the certificate in DER format
+     * It does the same as the fingerprint commandline option in x509
+     * command. For example:
+     *
+     *        $ openssl x509 -in cert_file -fingerprint -sha1
+     *        $ openssl x509 -in cert_file -fingerprint -md5
+     */
+
+    private function calculate_fingerprints () {
+
+        // Convert the certificate to DER and calculate the digest
+
+        $pem_cert = $this->keypair['certificate'];
+
+        $from_pos = strpos($pem_cert, "-----BEGIN CERTIFICATE-----");
+        if ( $from_pos === false ) {
+            throw new CryptException("Certificate not in PEM format");
+        }
+        $from_pos = $from_pos + 27;
+
+        $to_pos = strpos($pem_cert, "-----END CERTIFICATE-----");
+        if ( $to_pos === false ) {
+            throw new CryptException("Certificate not in PEM format");
+        }
+
+        $der_cert = base64_decode(substr($pem_cert, $from_pos, $to_pos - $from_pos));
+        if ( $der_cert === FALSE ) {
+            throw new CryptException("Certificate not in PEM format");
+        }
+
+        $_sha1_fingerprint = sha1($der_cert);
+        if ( $_sha1_fingerprint === FALSE ) {
+            throw new CryptException("Error calculating sha1 fingerprint");
+        }
+        $_md5_fingerprint = md5($der_cert);
+        if ( $_md5_fingerprint === FALSE ) {
+            throw new CryptException("Error calculating md5 fingerprint");
+        }
+
+        unset($der_cert);
+
+        $_sha1_fingerprint = strtoupper($_sha1_fingerprint);
+        $_md5_fingerprint  = strtoupper($_md5_fingerprint);
+
+        $sha1_fingerprint = $_sha1_fingerprint[0];
+        for ( $i = 1, $to = strlen($_sha1_fingerprint); $i < $to ; $i++ ) {
+            if ( $i % 2 == 0 ) {
+                $sha1_fingerprint .= ":" . $_sha1_fingerprint[$i];
+            } else {
+                $sha1_fingerprint .= $_sha1_fingerprint[$i];
+            }
+        }
+
+        $md5_fingerprint = $_md5_fingerprint[0];
+        for ( $i = 1, $to = strlen($_md5_fingerprint); $i < $to ; $i++ ) {
+            if ( $i % 2 == 0 ) {
+                $md5_fingerprint .= ":" . $_md5_fingerprint[$i];
+            } else {
+                $md5_fingerprint .= $_md5_fingerprint[$i];
+            }
+        }
+
+        $this->keypair['sha1_fingerprint'] = $sha1_fingerprint;
+        $this->keypair['md5_fingerprint']  = $md5_fingerprint;
+
+    }
+
 }
 
 class PublicKey {
