@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage artefact-blog
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -58,52 +59,57 @@ class PluginArtefactBlog extends PluginArtefact {
     }
 
     public static function get_cron() {
+        return array();
+    }
+
+
+    public static function get_event_subscriptions() {
         return array(
             (object)array(
-                'callfunction' => 'clean_post_files',
-                'hour'         => '4',
-                'minute'       => '40'
-            )
+                'plugin'       => 'blog',
+                'event'        => 'createuser',
+                'callfunction' => 'create_default_blog',
+            ),
         );
     }
 
-    /**
-     * This function cleans out any files that have been uploaded, but which
-     * are not associated with a blog, because of an aborted blog creation.
-     */
-    public static function clean_post_files() {
+    public static function block_advanced_options_element($configdata, $artefacttype) {
+        $strartefacttype = get_string($artefacttype, 'artefact.blog');
+        return array(
+            'type' => 'fieldset',
+            'name' => 'advanced',
+            'collapsible' => true,
+            'collapsed' => false,
+            'legend' => get_string('moreoptions', 'artefact.blog'),
+            'elements' => array(
+                'copytype' => array(
+                    'type' => 'select',
+                    'title' => get_string('blockcopypermission', 'view'),
+                    'description' => get_string('blockcopypermissiondesc', 'view'),
+                    'defaultvalue' => isset($configdata['copytype']) ? $configdata['copytype'] : 'nocopy',
+                    'options' => array(
+                        'nocopy' => get_string('copynocopy', 'artefact.blog'),
+                        'reference' => get_string('copyreference', 'artefact.blog', $strartefacttype),
+                        'full' => get_string('copyfull', 'artefact.blog', $strartefacttype),
+                    ),
+                ),
+            ),
+        );
+    }
 
-        $bloguploadbase = get_config('dataroot') . ArtefactTypeBlogPost::$blogattachmentroot;
-        if (!$basedir = opendir($bloguploadbase)) {
-            // If the directory doesn't exist, it's likely that it hasn't been 
-            // created yet (i.e. nobody has uploaded any files)
-            return;
-        }
+    public static function create_default_blog($event, $user) {
+        $name = display_name($user, null, true);
+        $blog = new ArtefactTypeBlog(0, (object) array(
+            'title'       => get_string('defaultblogtitle', 'artefact.blog', $name),
+            'owner'       => $user['id'],
+        ));
+        $blog->commit();
+    }
 
-        $currenttime = time();
-
-        // Read through all the upload session directories
-        while (false !== ($sessionupload = readdir($basedir))) {
-            if ($sessionupload != "." && $sessionupload != "..") {
-                $sessionupload = $bloguploadbase . $sessionupload;
-                $subdir = opendir($sessionupload);
-
-                // Remove all files older than the session timeout plus two hours.
-                while (false !== ($uploadfile = readdir($subdir))) {
-                    if ($uploadfile != "." && $uploadfile != "..") {
-                        $uploadfile = $sessionupload . '/' . $uploadfile;
-                        if ($currenttime - filemtime($uploadfile) > get_config('session_timeout') + 7200) {
-                            unlink($uploadfile);
-                        }
-                    }
-                }
-
-                closedir($subdir);
-                rmdir($sessionupload);
-            }
-        }
-
-        closedir($basedir);
+    public static function get_artefact_type_content_types() {
+        return array(
+            'blogpost' => array('text'),
+        );
     }
 }
 
@@ -198,40 +204,71 @@ class ArtefactTypeBlog extends ArtefactType {
      * @return array  A two key array, 'html' and 'javascript'.
      */
     public function render_self($options) {
-        // This is because if there are multiple blocks on a page, they need separate
-        // js variables.
-        $blockid = isset($options['blockid'])
-            ? $options['blockid']
-            : mt_rand();
-
         $this->add_to_render_path($options);
 
         $smarty = smarty_core();
         if (isset($options['viewid'])) {
             $smarty->assign('artefacttitle', '<a href="' . get_config('wwwroot') . 'view/artefact.php?artefact='
                                              . $this->get('id') . '&view=' . $options['viewid']
-                                             . '">' . $this->get('title') . '</a>');
+                                             . '">' . hsc($this->get('title')) . '</a>');
         }
         else {
-            $smarty->assign('artefacttitle', $this->get('title'));
+            $smarty->assign('artefacttitle', hsc($this->get('title')));
         }
 
-        $smarty->assign('blockid', $blockid);
         $smarty->assign('options', $options);
-        $smarty->assign('enc_id', json_encode($this->id));
-        $smarty->assign('limit', self::pagination);
-        $smarty->assign('loading_img', theme_get_url('images/loading.gif'));
-        $smarty->assign('description', $this->get('description'));
+        $smarty->assign('description', clean_html($this->get('description')));
+        $smarty->assign('owner', $this->get('owner'));
+        $smarty->assign('tags', $this->get('tags'));
 
         // Remove unnecessary options for blog posts
         unset($options['hidetitle']);
-        $smarty->assign('enc_options', json_encode(json_encode($options)));
+
+        $page = (isset($options['page'])) ? abs(intval($options['page'])) : abs(param_integer('page', 1));
+        $offset = $page ? $page * self::pagination - self::pagination : 1;
+
+        $postids = get_column_sql("
+            SELECT a.id
+            FROM {artefact} a
+            LEFT JOIN {artefact_blog_blogpost} bp ON a.id = bp.blogpost
+            WHERE a.parent = ?
+            AND bp.published = 1
+            ORDER BY a.ctime DESC
+            LIMIT ? OFFSET ?", array($this->get('id'), self::pagination, $offset));
+        $postcount = $this->count_published_posts();
+
+        $data = array();
+        foreach($postids as $postid) {
+            $blogpost = new ArtefactTypeBlogPost($postid);
+            $data[] = array(
+                'id' => $postid,
+                'content' => $blogpost->render_self($options)
+            );
+        }
+        $smarty->assign('postdata', $data);
+
+        // Pagination
+        if ($postcount > self::pagination) {
+            $baselink = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->get('id');
+            if (isset($options['viewid'])) {
+                $baselink .= '&view=' . $options['viewid'];
+            }
+
+            if ($offset + self::pagination < $postcount) {
+                $smarty->assign('olderpostslink',  $baselink . '&page=' . ($page + 1));
+            }
+            if ($offset > 0) {
+                $smarty->assign('newerpostslink',  $baselink . '&page=' . ($page - 1));
+            }
+        }
 
         return array('html' => $smarty->fetch('blocktype:blog:blog_render_self.tpl'), 'javascript' => '');
     }
 
                 
     public static function get_icon($options=null) {
+        global $THEME;
+        return $THEME->get_url('images/blog.gif', false, 'artefact/blog');
     }
 
     public static function is_singular() {
@@ -247,21 +284,43 @@ class ArtefactTypeBlog extends ArtefactType {
      * @param User
      * @return array (count: integer, data: array)
      */
-    public static function get_blog_list(User $user, $limit = self::pagination, $offset = 0) {
+    public static function get_blog_list($limit, $offset) {
+        global $USER;
         ($result = get_records_sql_array("
-         SELECT id, title, description
-         FROM {artefact}
-         WHERE owner = ?
-          AND artefacttype = 'blog'
-         ORDER BY title
-         LIMIT ? OFFSET ?", array($user->get('id'), $limit, $offset)))
+         SELECT * FROM {artefact} WHERE owner = ? AND artefacttype = 'blog'
+         ORDER BY title LIMIT ? OFFSET ?", array($USER->get('id'), $limit, $offset)))
             || ($result = array());
 
-        $count = (int)get_field('artefact', 'COUNT(*)', 'owner', $user->get('id'), 'artefacttype', 'blog');
+        $count = (int)get_field('artefact', 'COUNT(*)', 'owner', $USER->get('id'), 'artefacttype', 'blog');
 
         return array($count, $result);
     }
 
+    public static function build_blog_list_html(&$blogs) {
+        $smarty = smarty_core();
+        $smarty->assign_by_ref('blogs', $blogs);
+        $blogs->tablerows = $smarty->fetch('artefact:blog:bloglist.tpl');
+        $pagination = build_pagination(array(
+            'id' => 'bloglist_pagination',
+            'class' => 'center',
+            'url' => get_config('wwwroot') . 'artefact/blog/index.php',
+            'jsonscript' => 'artefact/blog/index.json.php',
+            'datatable' => 'bloglist',
+            'count' => $blogs->count,
+            'limit' => $blogs->limit,
+            'offset' => $blogs->offset,
+            'firsttext' => '',
+            'previoustext' => '',
+            'nexttext' => '',
+            'lasttext' => '',
+            'numbersincludefirstlast' => false,
+            'resultcounttextsingular' => get_string('blog', 'artefact.blog'),
+            'resultcounttextplural' => get_string('blogs', 'artefact.blog'),
+        ));
+        $blogs->pagination = $pagination['html'];
+        $blogs->pagination_js = $pagination['javascript'];
+    }
+
     /**
      * This function creates a new blog.
      *
@@ -307,6 +366,28 @@ class ArtefactTypeBlog extends ArtefactType {
             get_string('blogsettings', 'artefact.blog') => $wwwroot . 'artefact/blog/settings/?id=' . $id,
         );
     }
+
+    public function copy_extra($new) {
+        $new->set('title', get_string('Copyof', 'mahara', $this->get('title')));
+    }
+
+    /**
+     * Returns the number of posts in this blog that have been published.
+     *
+     * The result of this function looked up from the database each time, so 
+     * cache it if you know it's safe to do so.
+     *
+     * @return int
+     */
+    public function count_published_posts() {
+        return (int)get_field_sql("
+            SELECT COUNT(*)
+            FROM {artefact} a
+            LEFT JOIN {artefact_blog_blogpost} bp ON a.id = bp.blogpost
+            WHERE a.parent = ?
+            AND bp.published = 1", array($this->get('id')));
+    }
+
 }
 
 /**
@@ -330,32 +411,36 @@ class ArtefactTypeBlogPost extends ArtefactType {
     public function __construct($id = 0, $data = null) {
         parent::__construct($id, $data);
 
-        if (!$data) {
-            if ($this->id) {
-                if ($bpdata = get_record('artefact_blog_blogpost', 'blogpost', $this->id)) {
-                    foreach($bpdata as $name => $value) {
-                        if (property_exists($this, $name)) {
-                            $this->$name = $value;
-                        }
+        if ($this->id) {
+            if ($bpdata = get_record('artefact_blog_blogpost', 'blogpost', $this->id)) {
+                foreach($bpdata as $name => $value) {
+                    if (property_exists($this, $name)) {
+                        $this->$name = $value;
                     }
                 }
-                else {
-                    // This should never happen unless the user is playing around with blog post IDs in the location bar or similar
-                    throw new ArtefactNotFoundException(get_string('blogpostdoesnotexist', 'artefact.blog'));
-                }
+            }
+            else {
+                // This should never happen unless the user is playing around with blog post IDs in the location bar or similar
+                throw new ArtefactNotFoundException(get_string('blogpostdoesnotexist', 'artefact.blog'));
             }
         }
     }
 
     /**
-     * This function extends ArtefactType::commit() by adding additional data
+     * This method extends ArtefactType::commit() by adding additional data
      * into the artefact_blog_blogpost table.
+     *
+     * This method also works out what blockinstances this blogpost is in, and 
+     * informs them that they should re-check what artefacts they have in them.
+     * The post content may now link to different artefacts. See {@link 
+     * PluginBlocktypeBlogPost::get_artefacts for more information}
      */
     public function commit() {
         if (empty($this->dirty)) {
             return;
         }
 
+        db_begin();
         $new = empty($this->id);
       
         parent::commit();
@@ -374,6 +459,26 @@ class ArtefactTypeBlogPost extends ArtefactType {
             update_record('artefact_blog_blogpost', $data, 'blogpost');
         }
 
+        // We want to get all blockinstances that contain this blog post. That is currently:
+        // 1) All blogpost blocktypes with this post in it
+        // 2) All blog blocktypes with this posts's blog in it
+        //
+        // With these, we tell them to rebuild what artefacts they have in them, 
+        // since the post content could have changed and now have links to 
+        // different artefacts in it
+        $blockinstanceids = (array)get_column_sql('SELECT block
+            FROM {view_artefact}
+            WHERE artefact = ?
+            OR artefact = ?', array($this->get('id'), $this->get('parent')));
+        if ($blockinstanceids) {
+            require_once(get_config('docroot') . 'blocktype/lib.php');
+            foreach ($blockinstanceids as $id) {
+                $instance = new BlockInstance($id);
+                $instance->rebuild_artefact_list();
+            }
+        }
+
+        db_commit();
         $this->dirty = false;
     }
 
@@ -386,10 +491,12 @@ class ArtefactTypeBlogPost extends ArtefactType {
             return;
         }
 
-        delete_records('artefact_blog_blogpost_file', 'blogpost', $this->id);
+        db_begin();
+        $this->detach(); // Detach all file attachments
         delete_records('artefact_blog_blogpost', 'blogpost', $this->id);
       
         parent::delete();
+        db_commit();
     }
 
     /**
@@ -414,34 +521,34 @@ class ArtefactTypeBlogPost extends ArtefactType {
         if (empty($options['hidetitle'])) {
             if (isset($options['viewid'])) {
                 $smarty->assign('artefacttitle', '<a href="' . get_config('wwwroot') . 'view/artefact.php?artefact='
-                     . $this->get('id') . '&view=' . $options['viewid']
-                     . '">' . $this->get('title') . '</a>');
+                     . $this->get('id') . '&amp;view=' . $options['viewid']
+                     . '">' . hsc($this->get('title')) . '</a>');
             }
             else {
-                $smarty->assign('artefacttitle', $this->get('title'));
+                $smarty->assign('artefacttitle', hsc($this->get('title')));
             }
         }
 
         // We need to make sure that the images in the post have the right viewid associated with them
-        $postcontent = $this->get('description');
+        $postcontent = clean_html($this->get('description'));
         if (isset($options['viewid'])) {
             safe_require('artefact', 'file');
             $postcontent = ArtefactTypeFolder::append_view_url($postcontent, $options['viewid']);
         }
         $smarty->assign('artefactdescription', $postcontent);
         $smarty->assign('artefact', $this);
-        $attachments = $this->get_attached_files();
+        $attachments = $this->get_attachments();
         if ($attachments) {
             $this->add_to_render_path($options);
             require_once(get_config('docroot') . 'artefact/lib.php');
             foreach ($attachments as &$attachment) {
                 $f = artefact_instance_from_id($attachment->id);
                 $attachment->size = $f->describe_size();
-                $attachment->iconpath = $f->get_icon(array('id' => $attachment->id, 'viewid' => $options['viewid']));
-                $attachment->viewpath = get_config('wwwroot') . 'view/artefact.php?artefact=' . $attachment->id . '&view=' . $options['viewid'];
+                $attachment->iconpath = $f->get_icon(array('id' => $attachment->id, 'viewid' => isset($options['viewid']) ? $options['viewid'] : 0));
+                $attachment->viewpath = get_config('wwwroot') . 'view/artefact.php?artefact=' . $attachment->id . '&view=' . (isset($options['viewid']) ? $options['viewid'] : 0);
                 $attachment->downloadpath = get_config('wwwroot') . 'artefact/file/download.php?file=' . $attachment->id;
                 if (isset($options['viewid'])) {
-                    $attachment->downloadpath .= '&id=' . $options['viewid'];
+                    $attachment->downloadpath .= '&view=' . $options['viewid'];
                 }
             }
             $smarty->assign('attachments', $attachments);
@@ -454,53 +561,14 @@ class ArtefactTypeBlogPost extends ArtefactType {
     }
 
 
-    /**
-     * Returns an array of IDs of artefacts attached to this blogpost
-     */
-    public function attachment_id_list() {
-        if (!$list = get_column('artefact_blog_blogpost_file', 'file', 'blogpost', $this->get('id'))) {
-            $list = array();
-        }
-        return $list;
-    }
-
-    public function attach_file($artefactid) {
-        $data = new StdClass;
-        $data->blogpost = $this->get('id');
-        $data->file = $artefactid;
-        insert_record('artefact_blog_blogpost_file', $data);
-
-        $data = new StdClass;
-        $data->artefact = $artefactid;
-        $data->parent = $this->get('id');
-        $data->dirty = true;
-        insert_record('artefact_parent_cache', $data);
-
-        // Ensure the attachment is recorded as being related to the blog as well
-        $data = new StdClass;
-        $data->artefact = $artefactid;
-        $data->parent = $this->get('parent');
-        $data->dirty = 0;
-
-        $where = $data;
-        unset($where->dirty);
-        ensure_record_exists('artefact_parent_cache', $where, $data);
-    }
-
-    public function detach_file($artefactid) {
-        delete_records('artefact_blog_blogpost_file', 'blogpost', $this->get('id'), 'file', $artefactid);
-        delete_records('artefact_parent_cache', 'parent', $this->get('id'), 'artefact', $artefactid);
-        // Remove the record relating the attachment with the blog
-        delete_records('artefact_parent_cache', 'parent', $this->get('parent'), 'artefact', $artefactid);
-    }
-
-
-    protected function count_attachments() {
-        return count_records('artefact_blog_blogpost_file', 'blogpost', $this->get('id'));
+    public function can_have_attachments() {
+        return true;
     }
 
 
     public static function get_icon($options=null) {
+        global $THEME;
+        return $THEME->get_url('images/blogpost.gif', false, 'artefact/blog');
     }
 
     public static function is_singular() {
@@ -520,7 +588,7 @@ class ArtefactTypeBlogPost extends ArtefactType {
      */
     public static function get_posts(User $user, $id, $limit = self::pagination, $offset = 0) {
         ($result = get_records_sql_assoc("
-         SELECT a.id, a.title, a.description, a.ctime, a.mtime, bp.published
+         SELECT a.id, a.title, a.description, " . db_format_tsfield('a.ctime', 'ctime') . ', ' . db_format_tsfield('a.mtime', 'mtime') . ", bp.published
          FROM {artefact} a
           LEFT OUTER JOIN {artefact_blog_blogpost} bp
            ON a.id = bp.blogpost
@@ -539,20 +607,23 @@ class ArtefactTypeBlogPost extends ArtefactType {
         $count = (int)get_field('artefact', 'COUNT(*)', 'owner', $user->get('id'), 
                                 'artefacttype', 'blogpost', 'parent', $id);
 
-        // Get the attached files.
         if (count($result) > 0) {
-            $idlist = implode(', ', array_map(create_function('$a', 'return $a->id;'), $result));
-            $files = get_records_sql_array('
-               SELECT
-                  bf.blogpost, bf.file, a.artefacttype, a.title, a.description
-               FROM {artefact_blog_blogpost_file} bf
-                  INNER JOIN {artefact} a ON bf.file = a.id
-               WHERE bf.blogpost IN (' . $idlist . ')', '');
+            // Get the attached files.
+            $files = ArtefactType::attachments_from_id_list(array_map(create_function('$a', 'return $a->id;'), $result));
             if ($files) {
-                foreach ($files as $file) {
-                    $result[$file->blogpost]->files[] = $file;
+                safe_require('artefact', 'file');
+                foreach ($files as &$file) {
+                    $file->icon = call_static_method(generate_artefact_class_name($file->artefacttype), 'get_icon', array('id' => $file->attachment));
+                    $result[$file->artefact]->files[] = $file;
                 }
             }
+
+            // Format dates properly
+            foreach ($result as &$post) {
+                $post->ctime = format_date($post->ctime, 'strftimedaydatetime');
+                $post->mtime = format_date($post->mtime);
+                $post->description = clean_html($post->description);
+            }
         }
 
         return array($count, array_values($result));
@@ -596,101 +667,6 @@ class ArtefactTypeBlogPost extends ArtefactType {
         return true;
     }
 
-    // Where to store temporary blog post files under dataroot
-    static $blogattachmentroot = 'artefact/blog/uploads/';
-
-
-    public static function get_temp_file_path($createid, $uploadnumber) {
-        return get_config('dataroot') . self::$blogattachmentroot 
-            . session_id() . $createid . '/' . $uploadnumber;
-    }
-
-
-    /**
-     * Returns the size of a temporary attachment
-     */
-    public static function temp_attachment_size($createid, $uploadnumber) {
-        return filesize(self::get_temp_file_path($createid, $uploadnumber));
-    }
-
-
-    /** 
-     * This function saves an uploaded file to a temporary directory in dataroot
-     *
-     */
-    public static function save_attachment_temporary($inputname, $dirname, $filename) {
-        require_once('uploadmanager.php');
-        $um = new upload_manager($inputname);
-        $result = new StdClass;
-        $tempdir = self::$blogattachmentroot . $dirname;
-        $result->error = $um->process_file_upload($tempdir, $filename);
-        $result->oldextension = $um->original_filename_extension();
-        $tempfile = $tempdir . '/' . $filename;
-        safe_require('artefact', 'file');
-        $result->type = ArtefactTypeFile::detect_artefact_type($tempfile);
-        return $result;
-    }
-
-
-    /**
-     * Save a temporary uploaded file to the myfiles area.
-     */
-    public function save_attachment($directory, $filename, $title, $description, $oldextension, $tags) {
-
-        // Create the blogfiles folder if it doesn't exist yet.
-        $blogfilesid = self::blogfiles_folder_id();
-        if (!$blogfilesid) {
-            return false;
-        }
-
-        global $USER;
-
-        safe_require('artefact', 'file');
-
-        $data = new StdClass;
-        $data->title = $title;
-        $data->description = $description;
-        $data->tags = $tags;
-        $data->owner = $USER->get('id');
-        $data->adminfiles = 0; // No admin blogs yet...
-        $data->parent = $blogfilesid;
-        $data->oldextension = $oldextension;
-        
-        $path = self::$blogattachmentroot . $directory . '/' . $filename;
-
-        if (!$fileid = ArtefactTypeFile::save_file($path, $data)) {
-            return false;
-        }
-
-        $this->attach_file($fileid);
-        return $fileid;
-    }
-
-    public static function blogfiles_folder_id($create = true) {
-        $name = get_string('blogfilesdirname', 'artefact.blog');
-        $description = get_string('blogfilesdirdescription', 'artefact.blog');
-        safe_require('artefact', 'file');
-        return ArtefactTypeFolder::get_folder_id($name, $description, null, null, $create);
-    }
-
-    // Change the name & description of a user's blogfiles folder when the user changes language pref
-    public static function change_language($userid, $oldlang, $newlang) {
-        $oldname = get_string_from_language($oldlang, 'blogfilesdirname', 'artefact.blog');
-        safe_require('artefact', 'file');
-        $blogfiles = ArtefactTypeFolder::get_folder_by_name($oldname, null, $userid);
-        if (empty($blogfiles)) {
-            return;
-        }
-
-        $name = get_string_from_language($newlang, 'blogfilesdirname', 'artefact.blog');
-        $description = get_string_from_language($newlang, 'blogfilesdirdescription', 'artefact.blog');
-        if (!empty($name)) {
-            $blogfiles = artefact_instance_from_id($blogfiles->id);
-            $blogfiles->set('title', $name);
-            $blogfiles->set('description', $description);
-            $blogfiles->commit();
-        }
-    }
 
     /**
      * This function publishes the blog post.
@@ -716,27 +692,6 @@ class ArtefactTypeBlogPost extends ArtefactType {
         return true;
     }
 
-    /**
-     * This function returns a list of files attached to a post to use
-     * when displaying or editing a blog post
-     *
-     * @return array
-     */
-    public function get_attached_files() {
-        $list = get_records_sql_array('SELECT a.id, a.artefacttype, a.title, a.description 
-            FROM {artefact_blog_blogpost_file} f
-            INNER JOIN {artefact} a ON a.id = f.file
-            WHERE f.blogpost = ?
-            ORDER BY a.title', array($this->id));
-
-        // load tags
-        if ($list) {
-            foreach ( $list as &$attachment ) {
-                $attachment->tags = join(', ', get_column('artefact_tag', 'tag', 'artefact', $attachment->id));
-            }
-        }
-        return $list;
-    }
     
     public static function get_links($id) {
         $wwwroot = get_config('wwwroot');
@@ -745,6 +700,61 @@ class ArtefactTypeBlogPost extends ArtefactType {
             '_default'                                  => $wwwroot . 'artefact/blog/post.php?blogpost=' . $id,
         );
     }
+
+    public function update_artefact_references(&$view, &$template, &$artefactcopies, $oldid) {
+        parent::update_artefact_references($view, $template, $artefactcopies, $oldid);
+        // Attach copies of the files that were attached to the old post.
+        // Update <img> tags in the post body to refer to the new image artefacts.
+        $regexp = array();
+        $replacetext = array();
+        if (isset($artefactcopies[$oldid]->oldattachments)) {
+            foreach ($artefactcopies[$oldid]->oldattachments as $a) {
+                if (isset($artefactcopies[$a])) {
+                    $this->attach($artefactcopies[$a]->newid);
+                }
+                $regexp[] = '#<img([^>]+)src="' . get_config('wwwroot') . 'artefact/file/download.php\?file=' . $a . '"#';
+                $replacetext[] = '<img$1src="' . get_config('wwwroot') . 'artefact/file/download.php?file=' . $artefactcopies[$a]->newid . '"';
+            }
+            $this->set('description', preg_replace($regexp, $replacetext, $this->get('description')));
+        }
+    }
+
+    /**
+     * During the copying of a view, we might be allowed to copy
+     * blogposts but not the containing blog.  We need to create a new
+     * blog to hold the copied posts.
+     */
+    public function default_parent_for_copy(&$view, &$template, $artefactstoignore) {
+        static $blogid;
+
+        if (!empty($blogid)) {
+            return $blogid;
+        }
+
+        $blogname = get_string('viewposts', 'artefact.blog', $view->get('id'));
+        $data = (object) array(
+            'title'       => $blogname,
+            'description' => get_string('postscopiedfromview', 'artefact.blog', $template->get('title')),
+            'owner'       => $view->get('owner'),
+            'group'       => $view->get('group'),
+            'institution' => $view->get('institution'),
+        );
+        $blog = new ArtefactTypeBlog(0, $data);
+        $blog->commit();
+
+        $blogid = $blog->get('id');
+
+        return $blogid;
+    }
+
+    /**
+     * Looks through the blog post text for links to download artefacts, and 
+     * returns the IDs of those artefacts.
+     */
+    public function get_referenced_artefacts_from_postbody() {
+        return artefact_get_references_in_html($this->get('description'));
+    }
 }
 
+
 ?>
