@@ -859,9 +859,10 @@ class ArtefactTypeFile extends ArtefactTypeFileBase {
         }
         $data->size = $size;
 
-        // the browser wasn't sure, so use mime_content_type to guess
-        if($um->file['type'] == 'application/octet-stream') {
-            $data->filetype = mime_content_type($um->file['tmp_name']);
+        if ($um->file['type'] == 'application/octet-stream') {
+            // the browser wasn't sure, so use file_mime_type to guess
+            require_once('file.php');
+            $data->filetype = file_mime_type($um->file['tmp_name']);
         }
         else {
             $data->filetype = $um->file['type'];
