@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage auth-internal
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -78,7 +79,7 @@ class AuthInternal extends Auth {
      * @return bool            Whether the password is valid
      */
     public function is_password_valid($password) {
-        if (!preg_match('/^[a-zA-Z0-9 ~!#\$%\^&\*\(\)_\-=\+\,\.<>\/\?;:"\[\]\{\}\\\|`\']{6,}$/', $password)) {
+        if (!preg_match('/^[a-zA-Z0-9 ~!@#\$%\^&\*\(\)_\-=\+\,\.<>\/\?;:"\[\]\{\}\\\|`\']{6,}$/', $password)) {
             return false;
         }
         // The password must have at least one digit and two letters in it
@@ -170,7 +171,10 @@ class AuthInternal extends Auth {
             // This allows "plaintext" passwords, which are eaiser for an admin to
             // create by hacking in the database directly. The application does not
             // create passwords in this form.
-            return $theysent == $wehave;
+            // We don't allow empty passwords here to prevent anyone logging in to
+            // user accounts that were created by some other passwordless auth
+            // method and subsequently changed to internal.
+            return $wehave != '' && $theysent == $wehave;
         }
 
         if ($salt == '*') {
