@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage auth-xmlrpc
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  * This file incorporates work covered by the following copyright and
  * permission notice:
@@ -60,12 +61,10 @@ require_once(get_config('libroot') .'institution.php');
 $token         = param_variable('token');
 $remotewwwroot = param_variable('idp');
 $wantsurl      = param_variable('wantsurl', '/');
+$remoteurl     = param_boolean('remoteurl');
 
-$institution = new Institution();
-
-try {
-    $institution->findByWwwroot($remotewwwroot);
-} catch (ParamOutOfRangeException $e) {
+$len = strlen($remotewwwroot);
+if ($len < 1 || $len > 255) {
     throw new ParameterException(get_string('errnoxmlrpcwwwroot','auth', $remotewwwroot));
 }
 
@@ -88,16 +87,22 @@ $rpcconfigured = false;
 $res = false;
 foreach($instances as $instance) {
     if ($instance->authname == 'xmlrpc') {
-        $rpcconfigured = true;
-        try {
-            $auth = new AuthXmlrpc($instance->id);
-            $res = $auth->request_user_authorise($token, $remotewwwroot);
-        } catch (AccessDeniedException $e) {
-            continue;
-            // we don't care - a future plugin might accept the user
+        if (!$instance->suspended) {
+            $rpcconfigured = true;
+            try {
+                $auth = new AuthXmlrpc($instance->id);
+                $res = $auth->request_user_authorise($token, $remotewwwroot);
+            } catch (AccessDeniedException $e) {
+                continue;
+                // we don't care - a future plugin might accept the user
+            }
+            if ($res == true) {
+                break;
+            }
         }
-        if ($res == true) {
-            break;
+        else {
+          $sitename = get_config('sitename');
+          throw new AccessTotallyDeniedException(get_string('accesstotallydenied_institutionsuspended', 'mahara', $instance->displayname, $sitename));
         }
     }
 }
@@ -106,6 +111,9 @@ if ($res == true) {
     // Everything's ok - we have an authenticated User object
     // confirm the MNET session
     // redirect
+    if ($remoteurl) {
+        redirect($remotewwwroot . $wantsurl);
+    }
     redirect(get_config('wwwroot') . $wantsurl);
     // Redirect exits
 }
