@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage blocktype-externalvideo
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -54,15 +55,15 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
         return array('fileimagevideo');
     }
 
-    public static function render_instance(BlockInstance $instance) {
+    public static function render_instance(BlockInstance $instance, $editing=false) {
         $configdata = $instance->get('configdata');
         $result = '';
-        $url    = hsc(self::make_video_url($configdata['videoid']));
         $width  = (!empty($configdata['width'])) ? hsc($configdata['width']) : self::$default_width;
         $height = (!empty($configdata['height'])) ? hsc($configdata['height']) : self::$default_height;
 
         if (isset($configdata['videoid'])) {
-            $result  = '<div class="center">';
+            $url     = hsc(self::make_video_url($configdata['videoid']));
+            $result .= '<div class="mediaplayer-container center"><div class="mediaplayer">';
             $result .= '<object width="' . $width . '" height="' . $height . '">';
             $result .= '<param name="movie" value="' . $url . '"></param>';
             $result .= '<param name="wmode" value="transparent"></param>';
@@ -70,7 +71,7 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
             $result .= '<embed src="' . $url . '" ';
             $result .= 'type="application/x-shockwave-flash" wmode="transparent" width="' . $width . '" ';
             $result .= 'height="' . $height . '" allowscriptaccess="never"></embed></object>';
-            $result .= '</div>';
+            $result .= '</div></div>';
         }
 
         return $result;
@@ -88,7 +89,7 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
                 'title' => get_string('videourl','blocktype.externalvideo'),
                 'description' => get_string('videourldescription2','blocktype.externalvideo') . self::get_html_of_supported_websites(),
                 'width' => '90%',
-                'defaultvalue' => $configdata['videoid'],
+                'defaultvalue' => isset($configdata['videoid']) ? $configdata['videoid'] : null,
                 'rules' => array(
                     'required' => true
                 ),
@@ -124,8 +125,8 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
         static $embedsources = array(
             // www.youtube.com
             array(
-                'match' => '#.*youtube\.com.*v(=|\/)([a-zA-Z0-9_-]+).*#',
-                'url'   => 'http://www.youtube.com/v/$2'
+                'match' => '#.*youtube\.com.*(v|(cp))(=|\/)([a-zA-Z0-9_=-]+).*#',
+                'url'   => 'http://www.youtube.com/$1/$4'
             ),
             // video.google.com
             array(
@@ -137,6 +138,10 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
                 'match' => '#.*teachertube.com/flvideo/([0-9]+)\.flv.*#',
                 'url'   => 'http://www.teachertube.com/skin-p/mediaplayer.swf?file=http://www.teachertube.com/flvideo/$1.flv'
             ),
+            array(
+                'match' => '#.*teachertube\.com/viewVideo\.php\?video_id=(\d+).*#',
+                'url'   => 'http://www.teachertube.com/embed/player.swf?file=http://www.teachertube.com/embedFLV.php?pg=video_$1'
+            ),
             // www.scivee.tv
             array(
                 'match' => '#.*scivee.tv/node/([0-9]+).*#',
@@ -165,11 +170,16 @@ class PluginBlocktypeExternalvideo extends SystemBlocktype {
 <ul style="list-style-type: none;">
     <li><a href="http://www.youtube.com/" target="_blank"><img src="http://www.youtube.com/favicon.ico" alt="YouTube"> youtube.com</a></li>
     <li><a href="http://video.google.com/" target="_blank"><img src="http://video.google.com/favicon.ico" alt="Google Video"> video.google.com</a></li>
-    <li><a href="http://www.teachertube.com/" target="_blank"><img src="http://www.teachertube.com/images/favicon.ico" alt="TeacherTube"> teachertube.com</a></li>
+    <li><a href="http://www.teachertube.com/" target="_blank"><img src="http://www.teachertube.com/favicon.ico" alt="TeacherTube"> teachertube.com</a></li>
     <li><a href="http://www.scivee.tv/" target="_blank"><img src="http://www.scivee.tv/favicon.ico" alt="SciVee"> scivee.tv</a></li>
 </ul>
 EOF;
     }
+
+    public static function default_copy_type() {
+        return 'full';
+    }
+
 }
 
 ?>
