@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage blocktype-textbox
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -40,12 +41,29 @@ class PluginBlocktypeTextbox extends SystemBlocktype {
         return array('general');
     }
 
-    public static function render_instance(BlockInstance $instance) {
+    public static function render_instance(BlockInstance $instance, $editing=false) {
         $configdata = $instance->get('configdata');
         $text = (isset($configdata['text'])) ? $configdata['text'] : '';
         safe_require('artefact', 'file');
         $text = ArtefactTypeFolder::append_view_url($text,$instance->get('view'));
-        return $text;
+        return clean_html($text);
+    }
+
+    /**
+     * Returns a list of artefact IDs that are in this blockinstance.
+     *
+     * People may embed artefacts as images etc. They show up as links to the 
+     * download script, which isn't much to go on, but should be enough for us 
+     * to detect that the artefacts are therefore 'in' this blocktype.
+     */
+    public static function get_artefacts(BlockInstance $instance) {
+        $artefacts = array();
+        $configdata = $instance->get('configdata');
+        if (isset($configdata['text'])) {
+            require_once(get_config('docroot') . 'artefact/lib.php');
+            $artefacts = artefact_get_references_in_html($configdata['text']);
+        }
+        return $artefacts;
     }
 
     public static function has_instance_config() {
@@ -56,15 +74,19 @@ class PluginBlocktypeTextbox extends SystemBlocktype {
         $configdata = $instance->get('configdata');
         return array(
             'text' => array(
-                'type' => 'tinywysiwyg',
+                'type' => 'wysiwyg',
                 'title' => get_string('blockcontent', 'blocktype.textbox'),
                 'width' => '90%',
                 'height' => '150px',
-                'defaultvalue' => $configdata['text'],
+                'defaultvalue' => isset($configdata['text']) ? $configdata['text'] : '',
             ),
         );
     }
 
+    public static function default_copy_type() {
+        return 'full';
+    }
+
 }
 
 ?>
