@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -114,8 +115,8 @@ $form = array(
 function forgotpass_validate(Pieform $form, $values) {
     // See if the user input an email address or a username. We favour email addresses
     if (!$form->get_error('emailusername')) {
-        if (!($authinstance = get_field('usr', 'authinstance', 'email', $values['emailusername']))) {
-            if (!($authinstance = get_field('usr', 'authinstance', 'username', $values['emailusername']))) {
+        if (!($authinstance = get_field_sql('SELECT authinstance FROM {usr} WHERE LOWER(email) = ?', array(strtolower($values['emailusername']))))) {
+            if (!($authinstance = get_field_sql('SELECT authinstance FROM {usr} WHERE LOWER(username) = ?', array(strtolower($values['emailusername']))))) {
                 $form->set_error('emailusername', get_string('forgotpassnosuchemailaddressorusername'));
             }
         }
@@ -135,8 +136,8 @@ function forgotpass_submit(Pieform $form, $values) {
     global $SESSION;
 
     try {
-        if (!$user = get_record('usr', 'email', $values['emailusername'])) {
-            if (!$user = get_record('usr', 'username', $values['emailusername'])) {
+        if (!$user = get_record_sql('SELECT * FROM {usr} WHERE LOWER(email) = ?', array(strtolower($values['emailusername'])))) {
+            if (!$user = get_record_sql('SELECT * FROM {usr} WHERE LOWER(username) = ?', array(strtolower($values['emailusername'])))) {
                 die_info(get_string('forgotpassnosuchemailaddressorusername'));
             }
         }
