@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage interaction
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -36,13 +37,11 @@ require_once('group.php');
 $id = param_integer('id');
 
 $instance = interaction_instance_from_id($id);
+define('GROUP', $instance->get('group'));
+$group = group_current_group();
 
-if (!$group = get_record('group', 'id', $instance->get('group'), 'deleted', 0)) {
-    throw new GroupNotFoundException(get_string('groupnotfound', 'group', $id));
-}
-
-$membership = user_can_access_group((int)$group->id);
-if (!(bool)($membership & (GROUP_MEMBERSHIP_OWNER | GROUP_MEMBERSHIP_ADMIN | GROUP_MEMBERSHIP_STAFF))) {
+$membership = group_user_access((int)$group->id);
+if ($membership != 'admin') {
     throw new AccessDeniedException(get_string('notallowedtodeleteinteractions', 'group'));
 }
 
@@ -68,11 +67,11 @@ $form = pieform(array(
     )
 ));
 
-$smarty = smarty(array('tablerenderer'), array(), array(), array('sideblocks' => array(interaction_sideblock($group->id))));
+$smarty = smarty(array('tablerenderer'));
 $smarty->assign('form', $form);
-$smarty->assign('heading', TITLE);
+$smarty->assign('heading', $group->name);
+$smarty->assign('subheading', TITLE);
 $smarty->assign('message', get_string('deleteinteractionsure', 'group'));
-$smarty->assign('group', $group);
 $smarty->display('interaction/delete.tpl');
 
 ?>
