@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage lang
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -47,6 +48,8 @@ $string['showtags'] = 'Show my tags';
 $string['errorprocessingform'] = 'There was an error with submitting this form. Please check the marked fields and try again.';
 $string['description'] = 'Description';
 $string['remove']  = 'Remove';
+$string['Close'] = 'Close';
+$string['Help'] = 'Help';
 
 $string['no']     = 'No';
 $string['yes']    = 'Yes';
@@ -56,6 +59,12 @@ $string['From'] = 'From';
 $string['To'] = 'To';
 $string['All'] = 'All';
 
+$string['enable'] = 'Enable';
+$string['disable'] = 'Disable';
+$string['pluginenabled'] = 'Plugin enabled';
+$string['plugindisabled'] = 'Plugin disabled';
+$string['pluginnotenabled'] = 'Plugin not enabled.  You must enable the %s plugin first.';
+
 $string['next']      = 'Next';
 $string['nextpage']  = 'Next page';
 $string['previous']  = 'Previous';
@@ -66,15 +75,43 @@ $string['last']      = 'Last';
 $string['lastpage']  = 'Last page';
 
 $string['accept'] = 'Accept';
+$string['memberofinstitutions'] = 'Member of %s';
 $string['reject'] = 'Reject';
 $string['sendrequest'] = 'Send request';
 $string['reason'] = 'Reason';
 $string['select'] = 'Select';
 
+// Tags
 $string['tags'] = 'Tags';
 $string['tagsdesc'] = 'Enter comma separated tags for this item.';
 $string['tagsdescprofile'] = 'Enter comma separated tags for this item. Items tagged with \'profile\' are displayed in your sidebar.';
 $string['youhavenottaggedanythingyet'] = 'You have not tagged anything yet';
+$string['mytags'] = 'My Tags';
+$string['Tag'] = 'Tag';
+$string['itemstaggedwith'] = 'Items tagged with "%s"';
+$string['numitems'] = '%s items';
+$string['searchresultsfor'] = 'Search results for';
+$string['alltags'] = 'All Tags';
+$string['sortalpha'] = 'Sort tags alphabetically';
+$string['sortfreq'] = 'Sort tags by frequency';
+$string['sortresultsby'] = 'Sort results by:';
+$string['date'] = 'Date';
+$string['filterresultsby'] = 'Filter results by:';
+$string['tagfilter_all'] = 'All';
+$string['tagfilter_file'] = 'Files';
+$string['tagfilter_image'] = 'Images';
+$string['tagfilter_text'] = 'Text';
+$string['tagfilter_view'] = 'Views';
+$string['edittags'] = 'Edit Tags';
+$string['selectatagtoedit'] = 'Select a tag to edit';
+$string['edittag'] = 'Edit <a href="%s">%s</a>';
+$string['editthistag'] = 'Edit This Tag';
+$string['edittagdescription'] = 'All items in your portfolio tagged "%s" will be updated';
+$string['deletetag'] = 'Delete <a href="%s">%s</a>';
+$string['confirmdeletetag'] = 'Do you really want to delete this tag from everything in your portfolio?';
+$string['deletetagdescription'] = 'Remove this tag from all items in your portfolio';
+$string['tagupdatedsuccessfully'] = 'Tag updated successfully';
+$string['tagdeletedsuccessfully'] = 'Tag deleted successfully';
 
 $string['selfsearch'] = 'Search My Portfolio';
 
@@ -95,14 +132,20 @@ $string['pendingfriends'] = 'pending friends';
 $string['profile'] = 'profile';
 $string['views'] = 'Views';
 
+// Online users sideblock strings
+$string['onlineusers'] = 'Online users';
+$string['lastminutes'] = 'Last %s minutes';
+
 // Links and resources sideblock
 $string['linksandresources'] = 'Links and Resources';
 
 // auth
+$string['accesstotallydenied_institutionsuspended'] = 'Your institution %s, has been suspended.  Until it is unsuspended, you will be unable to log in to %s.
+Please contact your institution for help.';
 $string['accessforbiddentoadminsection'] = 'You are forbidden from accessing the administration section';
 $string['accountdeleted'] = 'Sorry, your account has been deleted';
 $string['accountexpired'] = 'Sorry, your account has expired';
-$string['accountcreated'] = get_config('sitename') . ': New account';
+$string['accountcreated'] = '%s: New account';
 $string['accountcreatedtext'] = 'Dear %s,
 
 A new account has been created for you on %s. Your details are as follows:
@@ -110,7 +153,7 @@ A new account has been created for you on %s. Your details are as follows:
 Username: %s
 Password: %s
 
-Visit ' . get_config('wwwroot') . ' to get started!
+Visit %s to get started!
 
 Regards, %s Site Administrator';
 $string['accountcreatedchangepasswordtext'] = 'Dear %s,
@@ -122,25 +165,25 @@ Password: %s
 
 Once you log in for the first time, you will be asked to change your password.
 
-Visit ' . get_config('wwwroot') . ' to get started!
+Visit %s to get started!
 
 Regards, %s Site Administrator';
 $string['accountcreatedhtml'] = '<p>Dear %s</p>
 
-<p>A new account has been created for you on <a href="' . get_config('wwwroot') . '">%s</a>. Your details are as follows:</p>
+<p>A new account has been created for you on <a href="%s">%s</a>. Your details are as follows:</p>
 
 <ul>
     <li><strong>Username:</strong> %s</li>
     <li><strong>Password:</strong> %s</li>
 </ul>
 
-<p>Visit <a href="' . get_config('wwwroot') . '">' . get_config('wwwroot') . '</a> to get started!</p>
+<p>Visit <a href="%s">%s</a> to get started!</p>
 
 <p>Regards, %s Site Administrator</p>
 ';
 $string['accountcreatedchangepasswordhtml'] = '<p>Dear %s</p>
 
-<p>A new account has been created for you on <a href="' . get_config('wwwroot') . '">%s</a>. Your details are as follows:</p>
+<p>A new account has been created for you on <a href="%s">%s</a>. Your details are as follows:</p>
 
 <ul>
     <li><strong>Username:</strong> %s</li>
@@ -149,7 +192,7 @@ $string['accountcreatedchangepasswordhtml'] = '<p>Dear %s</p>
 
 <p>Once you log in for the first time, you will be asked to change your password.</p>
 
-<p>Visit <a href="' . get_config('wwwroot') . '">' . get_config('wwwroot') . '</a> to get started!</p>
+<p>Visit <a href="%s">%s</a> to get started!</p>
 
 <p>Regards, %s Site Administrator</p>
 ';
@@ -174,8 +217,8 @@ $string['accountexpirywarninghtml'] = '<p>Dear %s,</p>
 <p>If you wish to extend your account access or have any questions regarding the above, please feel free to <a href="%s">Contact Us</a>.</p>
 
 <p>Regards, %s Site Administrator</p>';
-$string['institutionexpirywarning'] = 'Institution membership expiry warning';
-$string['institutionexpirywarningtext'] = 'Dear %s,
+$string['institutionmembershipexpirywarning'] = 'Institution membership expiry warning';
+$string['institutionmembershipexpirywarningtext'] = 'Dear %s,
 
 Your membership of %s on %s will expire within %s.
 
@@ -184,12 +227,43 @@ If you wish to extend your membership or have any questions regarding the above,
 %s
 
 Regards, %s Site Administrator';
-$string['institutionexpirywarninghtml'] = '<p>Dear %s,</p>
-    
+$string['institutionmembershipexpirywarninghtml'] = '<p>Dear %s,</p>
+
 <p>Your membership of %s on %s will expire within %s.</p>
 
 <p>If you wish to extend your membership or have any questions regarding the above, please feel free to <a href="%s">Contact Us</a>.</p>
 
+<p>Regards, %s Site Administrator</p>';
+$string['institutionexpirywarning'] = 'Institution expiry warning';
+$string['institutionexpirywarningtext_institution'] = 'Dear %s,
+
+%s\'s membership of %s will expire within %s.
+
+If you wish to extend your institution\'s membership or have any questions regarding the above, please feel free to contact us:
+
+%s
+
+Regards, %s Site Administrator';
+$string['institutionexpirywarninghtml_institution'] = '<p>Dear %s,</p>
+
+<p>%s\'s membership of %s will expire within %s.</p>
+
+<p>If you wish to extend your institution\'s membership or have any questions regarding the above, please feel free to <a href="%s">Contact Us</a>.</p>
+
+<p>Regards, %s Site Administrator</p>';
+$string['institutionexpirywarningtext_site'] = 'Dear %s,
+
+The institution \'%s\' will expire within %s.
+
+You may wish to contact them to extend their membership of %s.
+
+Regards, %s Site Administrator';
+$string['institutionexpirywarninghtml_site'] = '<p>Dear %s,</p>
+
+<p>The institution \'%s\' will expire within %s.</p>
+
+<p>You may wish to contact them to extend their membership of %s.</p>
+
 <p>Regards, %s Site Administrator</p>';
 $string['accountinactive'] = 'Sorry, your account is currently inactive';
 $string['accountinactivewarning'] = 'Account inactivity warning';
@@ -216,6 +290,8 @@ $string['youraccounthasbeensuspended'] = 'Your account has been suspeneded';
 $string['youraccounthasbeenunsuspended'] = 'Your account has been unsuspeneded';
 $string['changepassword'] = 'Change Password';
 $string['changepasswordinfo'] = 'You are required to change your password before you can proceed.';
+$string['chooseusernamepassword'] = 'Choose your username and password';
+$string['chooseusernamepasswordinfo'] = 'You need a username and password to log in to %s.  Please choose them now.';
 $string['confirmpassword'] = 'Confirm password';
 $string['javascriptnotenabled'] = 'Your browser does not have javascript enabled for this site. Mahara requires javascript to be enabled before you can log in';
 $string['cookiesnotenabled'] = 'Your browser does not have cookies enabled, or is blocking cookies from this site. Mahara requires cookies to be enabled before you can log in';
@@ -239,7 +315,7 @@ $string['sessiontimedout'] = 'Your session has timed out, please enter your logi
 $string['sessiontimedoutpublic'] = 'Your session has timed out. You may <a href="%s">log in</a> to continue browsing';
 $string['sessiontimedoutreload'] = 'Your session has timed out. Reload the page to log in again';
 $string['username'] = 'Username';
-$string['preferredname'] = 'Preferred Name';
+$string['preferredname'] = 'Display Name';
 $string['usernamedescription'] = ' ';
 $string['usernamehelp'] = 'The username you have been given to access this system.';
 $string['youaremasqueradingas'] = 'You are masquerading as %s.';
@@ -253,6 +329,7 @@ $string['captchatitle'] = 'CAPTCHA Image';
 $string['captchaimage'] = 'CAPTCHA Image';
 $string['captchadescription'] = 'Enter the characters you see in the picture. Letters are not case sensitive';
 $string['captchaincorrect'] = 'Enter the letters as they are shown in the image';
+$string['Site'] = 'Site';
 
 // Misc. register stuff that could be used elsewhere
 $string['emailaddress'] = 'Email address';
@@ -265,7 +342,7 @@ $string['studentid'] = 'ID number';
 $string['displayname'] = 'Display name';
 $string['fullname'] = 'Full name';
 $string['registerstep1description'] = 'Welcome! To use this site you must first register. You must also agree to the <a href="terms.php">terms and conditions</a>. The data we collect here will be stored according to our <a href="privacy.php">privacy statement</a>.';
-$string['registerstep3fieldsoptional'] = '<h3>Choose an Optional Profile Image</h3><p>You have now successfully registered with ' . get_config('sitename') . '! You may now choose an optional profile icon to be displayed as your avatar.</p>';
+$string['registerstep3fieldsoptional'] = '<h3>Choose an Optional Profile Image</h3><p>You have now successfully registered with %s! You may now choose an optional profile icon to be displayed as your avatar.</p>';
 $string['registerstep3fieldsmandatory'] = '<h3>Fill Out Mandatory Profile Fields</h3><p>The following fields are required. You must fill them out before your registration is complete.</p>';
 $string['registeringdisallowed'] = 'Sorry, you cannot register for this system at this time';
 $string['membershipexpiry'] = 'Membership expires';
@@ -316,6 +393,7 @@ $string['forgotusernamepasswordemailmessagehtml'] = '<p>Dear %s,</p>
 
 <p>Regards, %s Site Administrator</p>';
 $string['forgotpassemailsendunsuccessful'] = 'Sorry, it appears that the e-mail could not be sent successfully. This is our fault, please try again shortly';
+$string['forgotpassemaildisabled'] = 'Sorry, email is disabled for the email address or username you entered. Please contact an administrator to reset your password.';
 $string['forgotpassnosuchemailaddressorusername'] = 'The email address or username you entered doesn\'t match any users for this site';
 $string['forgotpasswordenternew'] = 'Please enter your new password to continue';
 $string['nosuchpasswordrequest'] = 'No such password request';
@@ -330,16 +408,16 @@ You may continue to use %s with your current username %s, but you must set a new
 
 Please follow the link below to continue the reset process.
 
-' . get_config('wwwroot') . 'forgotpass.php?key=%s
+%sforgotpass.php?key=%s
 
-If you have any questsions regarding the above, please feel free to contact
+If you have any questions regarding the above, please feel free to contact
 us.
 
-' . get_config('wwwroot') . 'contact.php
+%scontact.php
 
 Regards, %s Site Administrator
 
-' . get_config('wwwroot') . 'forgotpass.php?key=%s';
+%sforgotpass.php?key=%s';
 $string['noinstitutionsetpassemailmessagehtml'] = '<p>Dear %s,</p>
 
 <p>You are no longer a member of %s.</p>
@@ -347,14 +425,15 @@ $string['noinstitutionsetpassemailmessagehtml'] = '<p>Dear %s,</p>
 
 <p>Please follow the link below to continue the reset process.</p>
 
-<p><a href="' . get_config('wwwroot') . 'forgotpass.php?key=%s">' . get_config('wwwroot') . 'forgotpass.php?key=%s</a></p>
+<p><a href="%sforgotpass.php?key=%s">%sforgotpass.php?key=%s</a></p>
 
-<p>If you have any questsions regarding the above, please feel free to <a href="' . get_config('wwwroot') . 'contact.php">contact us</a>.</p>
+<p>If you have any questions regarding the above, please feel free to <a href="%scontact.php">contact us</a>.</p>
 
 <p>Regards, %s Site Administrator</p>
 
-<p><a href="' . get_config('wwwroot') . 'forgotpass.php?key=%s">' . get_config('wwwroot') . 'forgotpass.php?key=%s</a></p>';
+<p><a href="%sforgotpass.php?key=%s">%sforgotpass.php?key=%s</a></p>';
 $string['debugemail'] = 'NOTICE: This e-mail was intended for %s <%s> but has been sent to you as per the "sendallemailto" configuration setting.';
+$string['divertingemailto'] = 'Diverting email to %s';
 
 
 // Expiry times
@@ -397,10 +476,15 @@ $string['findgroups']         = 'Find Groups';
 $string['returntosite']       = 'Return to Site';
 $string['siteadministration'] = 'Site Administration';
 $string['useradministration'] = 'User Administration';
+$string['viewmyprofilepage']  = 'View profile page';
+$string['editmyprofilepage']  = 'Edit profile page';
 
 $string['unreadmessages'] = 'unread messages';
 $string['unreadmessage'] = 'unread message';
 
+$string['siteclosed'] = 'The site is temporarily closed for a database upgrade.  Site administrators may log in.';
+$string['siteclosedlogindisabled'] = 'The site is temporarily closed for a database upgrade.  <a href="%s">Perform the upgrade now.</a>';
+
 // footer
 $string['termsandconditions'] = 'Terms and Conditions';
 $string['privacystatement']   = 'Privacy Statement';
@@ -431,8 +515,9 @@ $string['institutionmemberconfirmsubject'] = 'Institution membership confirmatio
 $string['institutionmemberconfirmmessage'] = 'You have been added as a member of %s.';
 $string['institutionmemberrejectsubject'] = 'Institution membership request declined';
 $string['institutionmemberrejectmessage'] = 'Your request for membership of %s was declined.';
-
-$string['emailname'] = 'Mahara System'; // robot! 
+$string['Memberships'] = 'Memberships';
+$string['Requests'] = 'Requests';
+$string['Invitations'] = 'Invitations';
 
 $string['config'] = 'Config';
 
@@ -479,6 +564,12 @@ $string['Artefact'] = 'Artefact';
 $string['Artefacts'] = 'Artefacts';
 $string['artefactnotfound'] = 'Artefact with id %s not found';
 $string['artefactnotrendered'] = 'Artefact not rendered';
+$string['nodeletepermission'] = 'You do not have permission to delete this artefact';
+$string['noeditpermission'] = 'You do not have permission to edit this artefact';
+$string['Permissions'] = 'Permissions';
+$string['republish'] = 'Publish';
+$string['view'] = 'View';
+$string['artefactnotpublishable'] = 'Artefact %s is not publishable in view %s';
 
 $string['belongingto'] = 'Belonging to';
 $string['allusers'] = 'All users';
@@ -499,14 +590,24 @@ $string['uploadedfiletoobig'] = 'The file was too big. Please ask your administr
 $string['notphpuploadedfile'] = 'The file was lost in the upload process. This should not happen, please contact your administrator for more information.';
 $string['virusfounduser'] = 'The file you have uploaded, %s, has been scanned by a virus checker and found to be infected! Your file upload was NOT successful.';
 $string['fileunknowntype'] = 'The type of your uploaded file could not be determined. Your file may be corrupted, or it could be a configuration problem. Please contact your administrator.';
-$string['filetypenotallowed'] = 'You are not allowed to upload files of this type. Please contact your administrator for more information.';
 $string['virusrepeatsubject'] = 'Warning: %s is a repeat virus uploader.';
 $string['virusrepeatmessage'] = 'The user %s has uploaded multiple files which have been scanned by a virus checker and found to be infected.';
 
+$string['phpuploaderror'] = 'An error occurred during file upload: %s (Error code %s)';
+$string['phpuploaderror_1'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';
+$string['phpuploaderror_2'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
+$string['phpuploaderror_3'] = 'The uploaded file was only partially uploaded.';
+$string['phpuploaderror_4'] = 'No file was uploaded.';
+$string['phpuploaderror_6'] = 'Missing a temporary folder.';
+$string['phpuploaderror_7'] = 'Failed to write file to disk.';
+$string['phpuploaderror_8'] = 'File upload stopped by extension.';
+$string['adminphpuploaderror'] = 'A file upload error was probably caused by your server configuration.';
+
 $string['youraccounthasbeensuspended'] = 'Your account has been suspended';
-$string['youraccounthasbeensuspendedtext'] = 'Your account has been suspended'; // @todo: more info?
+$string['youraccounthasbeensuspendedtext2'] = 'Your account at %s has been suspended by %s.'; // @todo: more info?
+$string['youraccounthasbeensuspendedreasontext'] = "Your account at %s has been suspended by %s. Reason:\n\n%s";
 $string['youraccounthasbeenunsuspended'] = 'Your account has been unsuspended';
-$string['youraccounthasbeenunsuspendedtext'] = 'Your account has been unsuspended'; // @todo: more info?
+$string['youraccounthasbeenunsuspendedtext2'] = 'Your account at %s has been unsuspended. You may once again log in and use the site.'; // can't provide a login link because we don't know how they log in - it might be by xmlrpc
 
 // size of stuff
 $string['sizemb'] = 'MB';
@@ -765,6 +866,24 @@ $string['country.zw'] = 'Zimbabwe';
 $string['system'] = 'System';
 $string['done'] = 'Done';
 $string['back'] = 'Back';
+$string['backto'] = 'Back to %s';
 $string['alphabet'] = 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
+$string['formatpostbbcode'] = 'You can format your post using BBCode. %sLearn more%s';
 
+// import related strings (maybe separated later)
+$string['importedfrom'] = 'Imported from %s';
+$string['incomingfolderdesc'] = 'Files imported from other networked hosts';
+$string['remotehost'] = 'Remote host %s';
+
+$string['Copyof'] = 'Copy of %s';
+
+// Profie views
+$string['loggedinusersonly'] = 'Logged in users only';
+$string['allowpublicaccess'] = 'Allow public (non logged in) access';
+$string['thisistheprofilepagefor'] = 'This is the profile page for %s';
+
+$string['pleasedonotreplytothismessage'] = "Please do not reply to this message.";
+$string['deleteduser'] = 'Deleted user';
+
+$string['recentupdates'] = 'Recent Updates';
 ?>
