@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -49,6 +50,13 @@ define('MAXRUNAGE', 300);
 
 require(dirname(dirname(__FILE__)).'/init.php');
 require_once(get_config('docroot') . 'artefact/lib.php');
+require_once(get_config('docroot') . 'import/lib.php');
+require_once(get_config('docroot') . 'export/lib.php');
+require_once(get_config('docroot') . 'lib/activity.php');
+
+if (!$maxrunage = get_config('maxrunage')) {
+    $maxrunage = MAXRUNAGE;
+}
 
 // This is here for debugging purposes, it allows us to fake the time to test
 // cron behaviour
@@ -60,7 +68,7 @@ else {
 }
 
 log_debug('---------- cron running ' . date('r', $now) . ' ----------');
-raise_memory_limit('64M');
+raise_memory_limit('128M');
 
 // for each plugin type
 foreach (plugin_types() as $plugintype) {
@@ -69,7 +77,7 @@ foreach (plugin_types() as $plugintype) {
     $jobs = get_records_select_array(
         $plugintype . '_cron',
         'nextrun >= ? AND nextrun < ?',
-        array(db_format_timestamp($now - MAXRUNAGE), db_format_timestamp($now)),
+        array(db_format_timestamp($now - $maxrunage), db_format_timestamp($now)),
         '',
         'plugin,callfunction,minute,hour,day,month,dayofweek,' . db_format_tsfield('nextrun')
     );
@@ -106,7 +114,7 @@ foreach (plugin_types() as $plugintype) {
     $jobs = get_records_select_array(
         $plugintype . '_cron',
         'nextrun < ? OR nextrun IS NULL',
-        array(db_format_timestamp($now - MAXRUNAGE)),
+        array(db_format_timestamp($now - $maxrunage)),
         '',
         'plugin,callfunction,minute,hour,day,month,dayofweek,nextrun'
     );
@@ -136,7 +144,7 @@ foreach (plugin_types() as $plugintype) {
 
 // and now the core ones (much simpler)
 if ($jobs = get_records_select_array('cron', 'nextrun >= ? AND nextrun < ?',
-    array(db_format_timestamp($now - MAXRUNAGE), db_format_timestamp($now)))) {
+    array(db_format_timestamp($now - $maxrunage), db_format_timestamp($now)))) {
     foreach ($jobs as $job) {
         log_debug("Running core cron " . $job->callfunction);
 
@@ -152,11 +160,11 @@ if ($jobs = get_records_select_array('cron', 'nextrun >= ? AND nextrun < ?',
 
 // and missed ones...
 if ($jobs = get_records_select_array('cron', 'nextrun < ? OR nextrun IS NULL',
-    array(db_format_timestamp($now - MAXRUNAGE)))) {
+    array(db_format_timestamp($now - $maxrunage)))) {
     foreach ($jobs as $job) {
       if ($job->nextrun) {
           log_warn('core cronjob "' . $job->callfunction 
-              . '" didn\'t get run because the nextrun time was too old');
+              . '" didn\'t get run because the nextrun time (' . $job->nextrun . ') was too old (less than ' . ($now - $maxrunage) . ')');
       }
       
       $nextrun = cron_next_run_time($now, (array)$job);
