@@ -1310,15 +1310,6 @@ function xmldb_core_upgrade($oldversion=0) {
             )");
     }
 
-    if ($oldversion < 2009111012) {
-        if ($records = get_records_sql_array("SELECT * FROM {artefact_file_files} WHERE filetype='application/octet-stream'", array())) {
-            foreach ($records as &$r) {
-                $path = get_config('dataroot') . 'artefact/file/originals/' . $r->fileid % 256 . '/' . $r->fileid;
-                set_field('artefact_file_files', 'filetype', mime_content_type($path), 'fileid', $r->fileid);
-            }
-        }
-    }
-
     return $status;
 
 }
