@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage form-element
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -38,9 +39,8 @@ function pieform_element_artefactchooser(Pieform $form, $element) {
     global $USER, $pagination_js;
 
     $value = $form->get_value($element);
-
     $element['offset'] = param_integer('offset', 0);
-    list($html, $pagination, $count) = View::build_artefactchooser_data($element);
+    list($html, $pagination, $count) = View::build_artefactchooser_data($element, $form->get_property('viewgroup'), $form->get_property('viewinstitution'));
 
     $smarty = smarty_core();
     $smarty->assign('datatable', $element['name'] . '_data');
@@ -55,7 +55,7 @@ function pieform_element_artefactchooser(Pieform $form, $element) {
     // managing stuff.
     $pagination_js = $pagination['javascript'];
 
-    $baseurl = view::make_base_url();
+    $baseurl = View::make_base_url();
     $smarty->assign('browseurl', $baseurl);
     $smarty->assign('searchurl', $baseurl . '&s=1');
     $smarty->assign('searchable', !empty($element['search']));
@@ -222,17 +222,14 @@ if (ul) {
                 sendjsonrequest(p.jsonScript, queryData, 'GET', function(data) {
                     var tbody = getFirstElementByTagAndClassName('tbody', null, p.datatable);
                     if (tbody) {
-                    //    var temp = DIV();
-                    //    temp.innerHTML = data['data']['tablerows'];
-                    //    swapDOM(tbody, temp);
                         if (
                             (document.all && document.documentElement && typeof(document.documentElement.style.maxHeight) != "undefined" && !window.opera)
                             ||
                             (/Konqueror|AppleWebKit|KHTML/.test(navigator.userAgent))) {
-                            var temp = $('ie-workaround');
-                            temp.innerHTML = '<table><tbody>' + data['data']['tablerows'];
+                            var temp = DIV({'id':'ie-workaround'});
+                            temp.innerHTML = '<table><tbody>' + data.data.tablerows + '</tbody></table>';
                             swapDOM(tbody, temp.childNodes[0].childNodes[0]);
-                            replaceChildNodes(temp);
+                            removeElement(temp);
                         }
                         else {
                             // This does not work in IE and Konqueror, the tbody 
