@@ -322,15 +322,6 @@ class Pieform {/*{{{*/
                     $element['title'] = '';
                 }
 
-                // Force the form method to post if there is a file to upload
-                if ($element['type'] == 'file') {
-                    $this->fileupload = true;
-                    if ($this->data['method'] == 'get') {
-                        $this->data['method'] = 'post';
-                        self::info("Your form '$this->name' had the method 'get' and also a file element - it has been converted to 'post'");
-                    }
-                }
-
                 // This function can be defined by the application using Pieforms,
                 // and applies to all elements of this type
                 $function = 'pieform_element_' . $element['type'] . '_configure';
@@ -350,6 +341,15 @@ class Pieform {/*{{{*/
                     $element = $function($element);
                 }
 
+                // Force the form method to post if there is a file to upload
+                if (!empty($element['needsmultipart'])) {
+                    $this->fileupload = true;
+                    if ($this->data['method'] == 'get') {
+                        $this->data['method'] = 'post';
+                        self::info("Your form '$this->name' had the method 'get' and also a file element - it has been converted to 'post'");
+                    }
+                }
+
                 // Add the autofocus flag to the element if required
                 if (!$autofocusadded && $this->data['autofocus'] === true && empty($element['nofocus'])) {
                     $element['autofocus'] = true;
@@ -529,6 +529,9 @@ class Pieform {/*{{{*/
         if ($this->has_errors()) {
             $result .= ' error';
         }
+        if (isset($this->data['class'])) {
+            $result .= ' ' . $this->data['class'];
+        }
         $result .= '"';
         foreach (array('name', 'method', 'action') as $attribute) {
             $result .= ' ' . $attribute . '="' . $this->data[$attribute] . '"';
@@ -668,8 +671,9 @@ class Pieform {/*{{{*/
         // form has been submitted the javascript from the first page load is 
         // still active in the document
         // 2) The form is NOT a JS form, but has a presubmitcallback
-        if (($this->data['jsform'] && !$this->submitted)
-            || (!$this->data['jsform'] && $this->data['presubmitcallback'])) {
+        if ($outputformtags &&
+            (($this->data['jsform'] && !$this->submitted)
+             || (!$this->data['jsform'] && $this->data['presubmitcallback']))) {
             // Establish which buttons in the form are submit buttons. This is 
             // used to detect which button was pressed to cause the form 
             // submission
@@ -690,6 +694,7 @@ class Pieform {/*{{{*/
                 'jsErrorCallback'       => $this->data['jserrorcallback'],
                 'globalJsErrorCallback' => $this->data['globaljserrorcallback'],
                 'postSubmitCallback'    => $this->data['postsubmitcallback'],
+                'newIframeOnSubmit'     => $this->data['newiframeonsubmit'],
             ));
             $result .= "<script type=\"text/javascript\">new Pieform($data);</script>\n";
         }
@@ -716,7 +721,7 @@ class Pieform {/*{{{*/
         if (isset($element['value'])) {
             return $element['value'];
         }
-        else if (isset($global[$element['name']]) && $element['type'] != 'submit') {
+        else if ($this->submitted && isset($global[$element['name']]) && $element['type'] != 'submit') {
             return $global[$element['name']];
         }
         else if (isset($element['defaultvalue'])) {
@@ -994,6 +999,10 @@ EOF;
             }
         }
 
+        if (isset($element['elementtitle'])) {
+            $result .= ' title="' . self::hsc($element['elementtitle']) . '"';
+        }
+
         if (!in_array('maxlength', $exclude) && isset($element['rules']['maxlength'])) {
             $result .= ' maxlength="' . intval($element['rules']['maxlength']) . '"';
         }
@@ -1051,7 +1060,7 @@ EOF;
      *                           can specify there own i18n strings for rules
      * @return string            The internationalised string
      */
-    public function i18n($plugin, $pluginname, $key, $element) {/*{{{*/
+    public function i18n($plugin, $pluginname, $key, $element=null) {/*{{{*/
         if (!in_array($plugin, array('element', 'renderer', 'rule'))) {
             throw new PieformException("Invalid plugin name '$plugin'");
         }
@@ -1067,6 +1076,7 @@ EOF;
         }
 
         // Fall back to the default string
+        $this->include_plugin($plugin, $pluginname);
         $function = 'pieform_' . $plugin . '_' . $pluginname . '_i18n';
         if (function_exists($function)) {
             $strings = $function();
@@ -1255,12 +1265,13 @@ EOF;
 
         // Element title
         if (isset($element['title']) && $element['title'] !== '') {
+            $title = (!empty($element['labelescaped'])) ? $element['title'] : self::hsc($element['title']);
             if (!empty($element['nolabel'])) {
                 // Don't bother with a label for the element
-                $element['labelhtml'] = self::hsc($element['title']);
+                $element['labelhtml'] = $title;
             }
             else {
-                $element['labelhtml'] = '<label for="' . $this->name . '_' . $element['id'] . '">' . Pieform::hsc($element['title']) . '</label>';
+                $element['labelhtml'] = '<label for="' . $this->name . '_' . $element['id'] . '">' . $title . '</label>';
             }
             if ($this->get_property('requiredmarker') && !empty($element['rules']['required'])) {
                 $element['labelhtml'] .= ' <span class="requiredmarker">*</span>';
@@ -1337,6 +1348,10 @@ EOF;
             // supported in less browsers. Most modern browsers should be fine)
             'jsform' => false,
 
+            // Whether the form will target a new hidden iframe every time it's
+            // submitted.
+            'newiframeonsubmit' => false,
+
             // The URL where pieforms.js and other related pieforms javascript 
             // files can be accessed. Best specified as an absolute path in 
             // pieform_configure()
