@@ -126,7 +126,7 @@ function pieform_element_calendar_get_value(Pieform $form, $element) {/*{{{*/
         return $element['value'];
     }
 
-    if (isset($global[$name])) {
+    if ($form->is_submitted() && isset($global[$name])) {
         if (trim($global[$name]) == '') {
             return null;
         }
@@ -167,6 +167,15 @@ function pieform_element_calendar_i18n() {/*{{{*/
         'es.utf8' => array(
             'invalidvalue' => 'Fecha/hora indicada inválida'
         ),
+        'sl.utf8' => array(
+            'invalidvalue' => 'Datum/čas ni določen pravilno'
+        ),
+        'nl.utf8' => array(
+            'invalidvalue' => 'Ongeldige tijd/datum opgegeven'
+        ),
+        'cs.utf8' => array(
+            'invalidvalue' => 'Neplatný datum/čas'
+        ),
 
     );
 }/*}}}*/
