@@ -47,7 +47,8 @@ function pieform_element_expiry(Pieform $form, $element) {/*{{{*/
         $seconds = $element['value'];
         $values = pieform_element_expiry_get_expiry_from_seconds($element['value']);
     }
-    else if (isset($global[$element['name']])
+    else if ($form->is_submitted()
+             && isset($global[$element['name']])
              && isset($global[$element['name'] . '_units'])) {
         $values = array('number' => $global[$element['name']],
                         'units'  => $global[$element['name'] . '_units']);
@@ -159,6 +160,27 @@ function pieform_element_expiry_i18n() {/*{{{*/
             'years'     => 'Años',
             'noenddate' => 'Sin fecha de finalización'
         ),
+        'sl.utf8' => array(
+            'days'      => 'dni',
+            'weeks'     => 'tednov',
+            'months'    => 'mesecev',
+            'years'     => 'let',
+            'noenddate' => 'ni zaključnega datuma'
+        ),
+        'nl.utf8' => array(
+            'days'      => 'Dagen',
+            'weeks'     => 'Weken',
+            'months'    => 'Maanden',
+            'years'     => 'Jaren',
+            'noenddate' => 'Geen einddatum'
+        ),
+        'cs.utf8' => array(
+            'days'      => 'dnů',
+            'weeks'     => 'týdnů',
+            'months'    => 'měsíců',
+            'years'     => 'roků',
+            'noenddate' => 'nikdy'
+        ),
 
     );
 }/*}}}*/
