@@ -57,9 +57,19 @@ function pieform_rule_before_i18n() {/*{{{*/
         'ja.utf8' => array(
             'before' => 'フィールド「 %s 」の後に設定することはできません'
         ),
-	'es.utf8' => array(
+        'es.utf8' => array(
             'before' => 'No puede ser posterior al campo "%s"'
         ),
+        'sl.utf8' => array(
+            'before' => 'To ne sme biti za poljem "%s"'
+        ),
+        'nl.utf8' => array(
+            'before' => 'Dit kan niet na het veld "%s" zijn'
+        ),
+        'cs.utf8' => array(
+            'before' => 'Zadaná hodnota nemůže být větší než v poli "%s"'
+        ),
+
     );
 }/*}}}*/
 
