@@ -37,7 +37,7 @@
  *                         the address.
  */
 function pieform_rule_email(Pieform $form, $value, $element) {/*{{{*/
-    if (!preg_match('/^[A-Za-z0-9\._%-]+@(?:[A-Za-z0-9-]+\.)+[a-z]{2,4}$/', $value)) {
+    if (!preg_match('/^[A-Za-z0-9+\._%-]+@(?:[A-Za-z0-9-]+\.)+[a-z]{2,4}$/', $value)) {
         return $form->i18n('rule', 'email', 'email', $element);
     }
 }/*}}}*/
@@ -59,6 +59,15 @@ function pieform_rule_email_i18n() {/*{{{*/
         'es.utf8' => array(
             'email' => 'Dirección de correo errónea'
         ),
+        'sl.utf8' => array(
+            'email' => 'Epoštni naslov je neveljaven'
+        ),
+        'nl.utf8' => array(
+            'email' => 'E-mailadres is ongeldig'
+        ),
+        'cs.utf8' => array(
+            'email' => 'Neplatná e-mailová adresa'
+        ),
 
     );
 }/*}}}*/
