@@ -53,6 +53,15 @@ function pieform_rule_minlength_i18n() {/*{{{*/
         'es.utf8' => array(
             'minlength' => 'Este campo debe tener como mínimo %d caracteres', 
         ),
+        'sl.utf8' => array(
+            'minlength' => 'To polje mora biti dolgo vsaj %d znakov',
+        ),
+        'nl.utf8' => array(
+            'minlength' => 'Dit veld moet minstens %d tekens lang zijn',
+        ),
+        'cs.utf8' => array(
+            'minlength' => 'Musíte zadat nejméně %d znaků',
+        ),
 
     );
 }/*}}}*/
