@@ -34,7 +34,7 @@
  * @return string            The error message, if the value is invalid.
  */
 function pieform_rule_minvalue(Pieform $form, $value, $element, $minvalue) {/*{{{*/
-    if ($value != '' && intval($value) < $minvalue) {
+    if ($value != '' && doubleval($value) < $minvalue) {
         return sprintf($form->i18n('rule', 'minvalue', 'minvalue', $element), $minvalue);
     }
 }/*}}}*/
@@ -56,6 +56,15 @@ function pieform_rule_minvalue_i18n() {/*{{{*/
         'es.utf8' => array(
             'minvalue' => 'Este valor no puede ser inferior a %d'
         ),
+        'sl.utf8' => array(
+            'minvalue' => 'Ta vrednost ne sme biti manjša od %d'
+        ),
+        'nl.utf8' => array(
+            'minvalue' => 'Deze waarde kan niet kleiner zijn dan %d'
+        ),
+        'cs.utf8' => array(
+            'minvalue' => 'Nemůžete zadat hodnotu menší než %d'
+        ),
 
     );
 }/*}}}*/
