@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  * @copyright  (C) portions from Moodle, (C) Martin Dougiamas http://dougiamas.com
  */
 
@@ -208,6 +209,9 @@ function get_admin_user_search_results($search, $offset, $limit, $sortby, $sortd
                 $queries[] = array('field' => 'lastname',
                                    'type' => 'contains',
                                    'string' => $word);
+                $queries[] = array('field' => 'username',
+                                   'type' => 'contains',
+                                   'string' => $word);
             }
         }
         foreach ($fullnames as $n) {
@@ -282,15 +286,8 @@ function build_admin_user_search_results($search, $offset, $limit, $sortby, $sor
     $searchurl = get_config('wwwroot') . 'admin/users/search.php?' . join('&amp;', $params)
         . '&amp;limit=' . $limit;
 
-    $usernametemplate = '<a href="' . get_config('wwwroot') . 'admin/users/edit.php?id={$r.id}">{$r.username|escape}</a>';
-    if (!$USER->get('admin')) {
-        // Only create the edit link if the returned user belongs to an institution that the viewer administers
-        $cond = array();
-        foreach ($USER->get('admininstitutions') as $i) {
-            $cond[] = 'isset($r.institutions.' . $i . ')';
-        }
-        $usernametemplate = '{if ' . join('||', $cond) . '}' . $usernametemplate . '{else}{$r.username}{/if}';
-    }
+    $usernametemplate = '<a href="' . get_config('wwwroot')
+        . '{if $USER->is_admin_for_user($r.id)}admin/users/edit.php?id={$r.id}{else}user/view.php?id={$r.id}{/if}">{$r.username|escape}</a>';
 
     $cols = array(
         'icon'        => array('name'     => '',
@@ -306,7 +303,7 @@ function build_admin_user_search_results($search, $offset, $limit, $sortby, $sor
     $institutions = get_records_assoc('institution', '', '', '', 'name,displayname');
     if (count($institutions) > 1) {
         $cols['institution'] = array('name'     => get_string('institution'),
-                                     'template' => '{if empty($r.institutions)}{$institutions.mahara->displayname}{else}{foreach from=$r.institutions item=i}<div>{$institutions[$i]->displayname}</div>{/foreach}{/if}{if !empty($r.requested)}{foreach from=$r.requested item=i}<div class="pending">{str tag=requestto section=admin} {$institutions[$i]->displayname}{if $USER->is_institutional_admin("$i")} (<a href="{$WWWROOT}admin/users/addtoinstitution.php?id={$r.id}&institution={$i}">{str tag=confirm section=admin}</a>){/if}</div>{/foreach}{/if}{if !empty($r.invitedby)}{foreach from=$r.invitedby item=i}<div class="pending">{str tag=invitedby section=admin} {$institutions[$i]->displayname}</div>{/foreach}{/if}');
+                                     'template' => '{if empty($r.institutions)}{$institutions.mahara->displayname|escape}{else}{foreach from=$r.institutions item=i}<div>{$institutions[$i]->displayname|escape}</div>{/foreach}{/if}{if !empty($r.requested)}{foreach from=$r.requested item=i}<div class="pending">{str tag=requestto section=admin} {$institutions[$i]->displayname|escape}{if $USER->is_institutional_admin("$i")} (<a href="{$WWWROOT}admin/users/addtoinstitution.php?id={$r.id}&institution={$i}">{str tag=confirm section=admin}</a>){/if}</div>{/foreach}{/if}{if !empty($r.invitedby)}{foreach from=$r.invitedby item=i}<div class="pending">{str tag=invitedby section=admin} {$institutions[$i]->displayname|escape}</div>{/foreach}{/if}');
     }
 
     $smarty = smarty_core();
@@ -331,6 +328,66 @@ function admin_user_search($queries, $constraints, $offset, $limit, $sortfield,
 }
 
 
+/**
+ * Returns search results for users in a particular group
+ *
+ * The search term is applied against first and last names of the users in the group
+ *
+ * @param int    $group  The group to build results for
+ * @param string $query  A search string to filter by
+ * @param int    $offset What result to start showing paginated results from
+ * @param int    $limit  How many results to show
+ * @param array  $extra  User membershiptype
+ *
+ */
+function get_group_user_search_results($group, $query, $offset, $limit, $membershiptype) {
+    $queries = array();
+    $constraints = array();
+    if (!empty($query)) {
+        list($words, $fullnames) = parse_name_query($query);
+        foreach ($words as $word) {
+            $queries[] = array('field' => 'firstname',
+                               'type' => 'contains',
+                               'string' => $word);
+            $queries[] = array('field' => 'lastname',
+                               'type' => 'contains',
+                               'string' => $word);
+        }
+        foreach ($fullnames as $n) {
+            $constraints[] = array('field' => 'firstname',
+                                   'type' => 'contains',
+                                   'string' => $n[0]);
+            $constraints[] = array('field' => 'lastname',
+                                   'type' => 'contains',
+                                   'string' => $n[1]);
+        }
+    }
+
+    $results = group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype);
+    if ($results['count']) {
+        $userids = array_map(create_function('$a', 'return $a["id"];'), $results['data']);
+        $introductions = get_records_sql_assoc("SELECT owner, title
+            FROM {artefact}
+            WHERE artefacttype = 'introduction'
+            AND owner IN (" . implode(',', db_array_to_ph($userids)) . ')',
+            $userids);
+        foreach ($results['data'] as &$result) {
+            $result['name'] = display_name($result);
+            $result['introduction'] = isset($introductions[$result['id']]) ? $introductions[$result['id']]->title : '';
+            $result['jointime'] = strftime(get_string('strftimedate'), $result['jointime']);
+        }
+    }
+    return $results;
+}
+
+
+function group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype) {
+    $plugin = get_config('searchplugin');
+    safe_require('search', $plugin);
+    return call_static_method(generate_class_name('search', $plugin), 'group_search_user', 
+                              $group, $queries, $constraints, $offset, $limit, $membershiptype);
+}
+
 /**
  * Given a query string and limits, return an array of matching groups using the
  * search plugin defined in config.php
@@ -378,6 +435,36 @@ function search_selfsearch($query_string, $limit, $offset, $type = 'all') {
     return call_static_method(generate_class_name('search', $plugin), 'self_search', $query_string, $limit, $offset, $type);
 }
 
+function get_portfolio_types_from_param($filter) {
+    if (is_null($filter) || $filter == 'all') {
+        return null;
+    }
+    if ($filter == 'view') {
+        return array('view' => true, 'artefact' => false);
+    }
+    require_once(get_config('docroot') . 'artefact/lib.php');
+    return array('view' => false, 'artefact' => artefact_get_types_from_filter($filter));
+}
+
+function get_portfolio_items_by_tag($tag, $owner, $limit, $offset, $sort='name', $type=null, $returntags=true) {
+    // For now, can only be used to search a user's portfolio
+    if (empty($owner->id) || empty($owner->type)) {
+        throw new SystemException('get_views_and_artefacts_by_tag: invalid owner');
+    }
+    if ($owner->type != 'user') {
+        throw new SystemException('get_views_and_artefacts_by_tag only implemented for users');
+    }
+
+    $types = get_portfolio_types_from_param($type);
+
+    $plugin = 'internal';
+    safe_require('search', $plugin);
+
+    $result = call_static_method(generate_class_name('search', $plugin), 'portfolio_search_by_tag', $tag, $owner, $limit, $offset, $sort, $types, $returntags);
+    $result->filter = $result->type = $type ? $type : 'all';
+    return $result;
+}
+
 function get_search_plugins() {
     $searchpluginoptions = array();
 
