@@ -380,6 +380,9 @@ function email_user($userto, $userfrom, $subject, $messagetext, $messagehtml='',
     }
     else {
         $usertoname = display_name($userto, $userto);
+        if (empty($userto->email)) {
+            throw new EmailException("Cannot send email to $usertoname with subject $subject.  User has no primary email address set.");
+        }
         $mail->AddAddress($userto->email, $usertoname );
     }
 
