@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -80,6 +81,7 @@ if (isset($key)) {
 
     function create_registered_user($profilefields=array()) {
         global $registration, $SESSION, $USER;
+        require_once(get_config('libroot') . 'user.php');
 
         db_begin();
 
@@ -99,25 +101,32 @@ if (isset($key)) {
         }
 
         $user = new User();
-        $user->username         = $registration->username;
-        $user->password         = $registration->password;
-        $user->salt             = $registration->salt;
-        $user->passwordchange   = 0;
         $user->active           = 1;
         $user->authinstance     = $authinstance->id;
         $user->firstname        = $registration->firstname;
         $user->lastname         = $registration->lastname;
         $user->email            = $registration->email;
-        $user->commit();
+        $user->username         = get_new_username($user->firstname . $user->lastname);
+        $user->passwordchange   = 1;
+        $user->salt             = substr(md5(rand(1000000, 9999999)), 2, 8);
 
-        $user->add_institution_request($registration->institution);
+        create_user($user, $profilefields);
+
+        // If the institution is 'mahara' then don't do anything
+        if ($registration->institution != 'mahara') {
+            $institutions = get_records_select_array('institution', "name != 'mahara'");
+
+            // If there is only one available, join it without requiring approval
+            if (count($institutions) == 1) {
+                $user->join_institution($registration->institution);
+            }
+            // Else, since there are multiple, request to join
+            else {
+                $user->add_institution_request($registration->institution);
+            }
+        }
 
-        $registration->id = $user->id;
 
-        // Insert standard stuff as artefacts
-        set_profile_field($user->id, 'email', $registration->email);
-        set_profile_field($user->id, 'firstname', $registration->firstname);
-        set_profile_field($user->id, 'lastname', $registration->lastname);
         if (!empty($registration->lang) && $registration->lang != 'default') {
             set_account_preference($user->id, 'lang', $registration->lang);
         }
@@ -125,17 +134,7 @@ if (isset($key)) {
         // Delete the old registration record
         delete_records('usr_registration', 'id', $registrationid);
 
-        // Set mandatory profile fields 
-        foreach(ArtefactTypeProfile::get_mandatory_fields() as $field => $type) {
-            // @todo here and above, use the method for getting "always mandatory" fields
-            if (in_array($field, array('firstname', 'lastname', 'email'))) {
-                continue;
-            }
-            set_profile_field($user->id, $field, $profilefields[$field]);
-        }
-
         db_commit();
-        handle_event('createuser', $registration);
 
         // Log the user in and send them to the homepage
         $USER = new LiveUser();
@@ -151,6 +150,7 @@ if (isset($key)) {
         else {
             $SESSION->add_ok_msg(get_string('registrationcomplete', 'mahara', get_config('sitename')));
         }
+        $SESSION->set('resetusername', true);
         redirect();
     }
     create_registered_user();
@@ -160,30 +160,6 @@ if (isset($key)) {
 // Default page - show the registration form
 
 $elements = array(
-    'username' => array(
-        'type' => 'text',
-        'title' => get_string('username'),
-        'rules' => array(
-            'required' => true
-        ),
-        'help' => true,
-    ),
-    'password1' => array(
-        'type' => 'password',
-        'title' => get_string('password'),
-        'description' => get_string('passwordformdescription', 'auth.internal'),
-        'rules' => array(
-            'required' => true
-        ),
-        'help' => true,
-    ),
-    'password2' => array(
-        'type' => 'password',
-        'title' => get_string('confirmpassword'),
-        'rules' => array(
-            'required' => true
-        )
-    ),
     'firstname' => array(
         'type' => 'text',
         'title' => get_string('firstname'),
@@ -233,10 +209,13 @@ if (count($institutions) > 1) {
         )
     );
 }
-else if ($institutions) {
+else if ($institutions) { // Only one option - probably mahara ('No Institution') but that's not certain
+
+    $institution = array_shift($institutions);
+
     $elements['institution'] = array(
         'type' => 'hidden',
-        'value' => 'mahara'
+        'value' => $institution->name
     );
 }
 else {
@@ -258,8 +237,7 @@ $elements['tandc'] = array(
     'separator' => ' &nbsp; '
 );
 
-$captcharequired = get_config('captcha_on_register_form');
-if (is_null($captcharequired) || $captcharequired) {
+if (get_config('captchaonregisterform')) {
     $elements['captcha'] = array(
         'type' => 'captcha',
         'title' => get_string('captchatitle'),
@@ -269,8 +247,8 @@ if (is_null($captcharequired) || $captcharequired) {
 }
 
 $elements['submit'] = array(
-    'type' => 'submitcancel',
-    'value' => array(get_string('register'), get_string('cancel'))
+    'type' => 'submit',
+    'value' => get_string('register'),
 );
 
 $form = array(
@@ -295,18 +273,6 @@ function register_validate(Pieform $form, $values) {
     $institution = $values['institution'];
     safe_require('auth', 'internal');
 
-    if (!$form->get_error('username') && !AuthInternal::is_username_valid($values['username'])) {
-        $form->set_error('username', get_string('usernameinvalidform', 'auth.internal'));
-    }
-
-    if (!$form->get_error('username') && record_exists_select('usr', 'LOWER(username) = ?', strtolower($values['username']))) {
-        $form->set_error('username', get_string('usernamealreadytaken', 'auth.internal'));
-    }
-
-    $user =(object) $values;
-    $user->authinstance = get_field('auth_instance', 'id', 'authname', 'internal', 'institution', $institution);
-    password_validate($form, $values, $user);
-
     // First name and last name must contain at least one non whitespace
     // character, so that there's something to read
     if (!$form->get_error('firstname') && !preg_match('/\S/', $values['firstname'])) {
@@ -330,8 +296,7 @@ function register_validate(Pieform $form, $values) {
     }
 
     // CAPTCHA image
-    $captcharequired = get_config('captcha_on_register_form');
-    if ((is_null($captcharequired) || $captcharequired) && !$values['captcha']) {
+    if (get_config('captchaonregisterform') && !$values['captcha']) {
         $form->set_error('captcha', get_string('captchaincorrect'));
     }
 
@@ -363,8 +328,6 @@ function register_submit(Pieform $form, $values) {
     // don't die_info, since reloading the page shows the login form.
     // instead, redirect to some other page that says this
     safe_require('auth', 'internal');
-    $values['salt']     = substr(md5(rand(1000000, 9999999)), 2, 8);
-    $values['password'] = AuthInternal::encrypt_password($values['password1'], $values['salt']);
     $values['key']   = get_random_key();
     // @todo the expiry date should be configurable
     $values['expiry'] = db_format_timestamp(time() + 86400);
@@ -372,16 +335,13 @@ function register_submit(Pieform $form, $values) {
     try {
         insert_record('usr_registration', $values);
 
-        $f = fopen('/tmp/donal.txt','w');
-        fwrite($f, get_string('registeredemailmessagetext', 'auth.internal', $values['firstname'], get_config('sitename'), $values['key'], get_config('sitename')));
-
         $user =(object) $values;
         $user->admin = 0;
         $user->staff = 0;
         email_user($user, null,
             get_string('registeredemailsubject', 'auth.internal', get_config('sitename')),
-            get_string('registeredemailmessagetext', 'auth.internal', $values['firstname'], get_config('sitename'), $values['key'], get_config('sitename')),
-            get_string('registeredemailmessagehtml', 'auth.internal', $values['firstname'], get_config('sitename'), $values['key'], $values['key'], get_config('sitename')));
+            get_string('registeredemailmessagetext', 'auth.internal', $values['firstname'], get_config('sitename'), get_config('wwwroot'), $values['key'], get_config('sitename')),
+            get_string('registeredemailmessagehtml', 'auth.internal', $values['firstname'], get_config('sitename'), get_config('wwwroot'), $values['key'], get_config('wwwroot'), $values['key'], get_config('sitename')));
     }
     catch (EmailException $e) {
         log_warn($e);
@@ -398,13 +358,9 @@ function register_submit(Pieform $form, $values) {
     redirect('/register.php');
 }
 
-function register_cancel_submit() {
-    redirect();
-}
-
 $smarty = smarty();
 $smarty->assign('register_form', pieform($form));
-$smarty->assign('heading', get_string('register'));
+$smarty->assign('PAGEHEADING', hsc(get_string('register')));
 $smarty->display('register.tpl');
 
 ?>
