@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -63,7 +64,7 @@ $form = pieform(array(
 ));
 
 $smarty = smarty();
-$smarty->assign('heading', TITLE);
+$smarty->assign('PAGEHEADING', hsc(TITLE));
 $smarty->assign('form', $form);
 $smarty->assign('user', $user);
 $smarty->display('user/requestfriendship.tpl');
@@ -96,8 +97,11 @@ function requestfriendship_submit(Pieform $form, $values) {
     else {
         $n->message = get_string_from_language($lang, 'requestedfriendlistmessage', 'group', $displayname);
     }
+    require_once('activity.php');
     activity_occurred('maharamessage', $n);
 
+    handle_event('addfriendrequest', array('requester' => $loggedinid, 'owner' => $id));
+
     $SESSION->add_ok_msg(get_string('friendformrequestsuccess', 'group', display_name($id)));
     switch (param_alpha('returnto', 'myfriends')) {
         case 'find':
